CVS commit: src/sys

2015-04-03 Thread Ryota Ozaki
Module Name:src
Committed By:   ozaki-r
Date:   Fri Apr  3 07:55:18 UTC 2015

Modified Files:
src/sys/net: if_ethersubr.c if_loop.c
src/sys/netinet: ip_output.c

Log Message:
Don't grab KERNEL_LOCK during if_output when NET_MPSAFE

The change makes L3 MP-safe work easy. At this point
we deal with only IP forwarding.

No functional change when NET_MPSAFE isn't enabled.


To generate a diff of this commit:
cvs rdiff -u -r1.205 -r1.206 src/sys/net/if_ethersubr.c
cvs rdiff -u -r1.80 -r1.81 src/sys/net/if_loop.c
cvs rdiff -u -r1.235 -r1.236 src/sys/netinet/ip_output.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/net/if_ethersubr.c
diff -u src/sys/net/if_ethersubr.c:1.205 src/sys/net/if_ethersubr.c:1.206
--- src/sys/net/if_ethersubr.c:1.205	Fri Nov 28 08:29:00 2014
+++ src/sys/net/if_ethersubr.c	Fri Apr  3 07:55:18 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_ethersubr.c,v 1.205 2014/11/28 08:29:00 ozaki-r Exp $	*/
+/*	$NetBSD: if_ethersubr.c,v 1.206 2015/04/03 07:55:18 ozaki-r Exp $	*/
 
 /*
  * Copyright (C) 1995, 1996, 1997, and 1998 WIDE Project.
@@ -61,7 +61,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: if_ethersubr.c,v 1.205 2014/11/28 08:29:00 ozaki-r Exp $);
+__KERNEL_RCSID(0, $NetBSD: if_ethersubr.c,v 1.206 2015/04/03 07:55:18 ozaki-r Exp $);
 
 #include opt_inet.h
 #include opt_atalk.h
@@ -70,6 +70,7 @@ __KERNEL_RCSID(0, $NetBSD: if_ethersubr
 #include opt_mpls.h
 #include opt_gateway.h
 #include opt_pppoe.h
+#include opt_net_mpsafe.h
 #include vlan.h
 #include pppoe.h
 #include bridge.h
@@ -214,7 +215,9 @@ ether_output(struct ifnet * const ifp0, 
 	struct at_ifaddr *aa;
 #endif /* NETATALK */
 
+#ifndef NET_MPSAFE
 	KASSERT(KERNEL_LOCKED_P());
+#endif
 
 #ifdef MBUFTRACE
 	m_claimm(m, ifp-if_mowner);

Index: src/sys/net/if_loop.c
diff -u src/sys/net/if_loop.c:1.80 src/sys/net/if_loop.c:1.81
--- src/sys/net/if_loop.c:1.80	Sat Jun  7 11:00:29 2014
+++ src/sys/net/if_loop.c	Fri Apr  3 07:55:18 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_loop.c,v 1.80 2014/06/07 11:00:29 rmind Exp $	*/
+/*	$NetBSD: if_loop.c,v 1.81 2015/04/03 07:55:18 ozaki-r Exp $	*/
 
 /*
  * Copyright (C) 1995, 1996, 1997, and 1998 WIDE Project.
@@ -65,14 +65,14 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: if_loop.c,v 1.80 2014/06/07 11:00:29 rmind Exp $);
+__KERNEL_RCSID(0, $NetBSD: if_loop.c,v 1.81 2015/04/03 07:55:18 ozaki-r Exp $);
 
 #include opt_inet.h
 #include opt_atalk.h
 #include opt_ipx.h
 #include opt_mbuftrace.h
 #include opt_mpls.h
-
+#include opt_net_mpsafe.h
 
 #include sys/param.h
 #include sys/systm.h
@@ -218,7 +218,9 @@ looutput(struct ifnet *ifp, struct mbuf 
 	size_t pktlen;
 
 	MCLAIM(m, ifp-if_mowner);
+#ifndef NET_MPSAFE
 	KASSERT(KERNEL_LOCKED_P());
+#endif
 
 	if ((m-m_flags  M_PKTHDR) == 0)
 		panic(looutput: no header mbuf);

Index: src/sys/netinet/ip_output.c
diff -u src/sys/netinet/ip_output.c:1.235 src/sys/netinet/ip_output.c:1.236
--- src/sys/netinet/ip_output.c:1.235	Tue Mar 31 08:44:43 2015
+++ src/sys/netinet/ip_output.c	Fri Apr  3 07:55:18 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: ip_output.c,v 1.235 2015/03/31 08:44:43 ozaki-r Exp $	*/
+/*	$NetBSD: ip_output.c,v 1.236 2015/04/03 07:55:18 ozaki-r Exp $	*/
 
 /*
  * Copyright (C) 1995, 1996, 1997, and 1998 WIDE Project.
@@ -91,11 +91,12 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ip_output.c,v 1.235 2015/03/31 08:44:43 ozaki-r Exp $);
+__KERNEL_RCSID(0, $NetBSD: ip_output.c,v 1.236 2015/04/03 07:55:18 ozaki-r Exp $);
 
 #include opt_inet.h
 #include opt_ipsec.h
 #include opt_mrouting.h
+#include opt_net_mpsafe.h
 
 #include sys/param.h
 #include sys/kmem.h
@@ -557,9 +558,13 @@ sendit:
 		if (__predict_true(
 		(m-m_pkthdr.csum_flags  M_CSUM_TSOv4) == 0 ||
 		(ifp-if_capenable  IFCAP_TSOv4) != 0)) {
+#ifndef NET_MPSAFE
 			KERNEL_LOCK(1, NULL);
+#endif
 			error = (*ifp-if_output)(ifp, m, sa, rt);
+#ifndef NET_MPSAFE
 			KERNEL_UNLOCK_ONE(NULL);
+#endif
 		} else {
 			error = ip_tso_output(ifp, m, sa, rt);
 		}
@@ -627,11 +632,15 @@ sendit:
 		} else {
 			KASSERT((m-m_pkthdr.csum_flags 
 			(M_CSUM_UDPv4 | M_CSUM_TCPv4)) == 0);
+#ifndef NET_MPSAFE
 			KERNEL_LOCK(1, NULL);
+#endif
 			error = (*ifp-if_output)(ifp, m,
 			(m-m_flags  M_MCAST) ?
 			sintocsa(rdst) : sintocsa(dst), rt);
+#ifndef NET_MPSAFE
 			KERNEL_UNLOCK_ONE(NULL);
+#endif
 		}
 	}
 	if (error == 0) {
@@ -1722,7 +1731,11 @@ ip_mloopback(struct ifnet *ifp, struct m
 
 	ip-ip_sum = 0;
 	ip-ip_sum = in_cksum(copym, ip-ip_hl  2);
+#ifndef NET_MPSAFE
 	KERNEL_LOCK(1, NULL);
+#endif
 	(void)looutput(ifp, copym, sintocsa(dst), NULL);
+#ifndef NET_MPSAFE
 	KERNEL_UNLOCK_ONE(NULL);
+#endif
 }



CVS commit: src/games/fortune/datfiles

2015-04-03 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Fri Apr  3 07:28:41 UTC 2015

Modified Files:
src/games/fortune/datfiles: fortunes2

Log Message:
properly pluralize.


To generate a diff of this commit:
cvs rdiff -u -r1.55 -r1.56 src/games/fortune/datfiles/fortunes2

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/games/fortune/datfiles/fortunes2
diff -u src/games/fortune/datfiles/fortunes2:1.55 src/games/fortune/datfiles/fortunes2:1.56
--- src/games/fortune/datfiles/fortunes2:1.55	Wed Mar 25 16:23:02 2015
+++ src/games/fortune/datfiles/fortunes2	Fri Apr  3 07:28:41 2015
@@ -24470,7 +24470,7 @@ the lives of both have been wasted.
 If the meanings of true and false were switched,
 then this sentence would not be false.
 %
-If the Nazi's had television with satellite technology, we'd all be
+If the Nazis had television with satellite technology, we'd all be
 goose-stepping.  Americans are just as suggestible.
 		-- Frank Zappa
 %



CVS commit: src/sys/net

2015-04-03 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Fri Apr  3 08:20:55 UTC 2015

Modified Files:
src/sys/net: if.h

Log Message:
 Use 1000ULL to prevent integer overflow (for IF_Gbps(10)). Same as OpenBSD.


To generate a diff of this commit:
cvs rdiff -u -r1.185 -r1.186 src/sys/net/if.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/net/if.h
diff -u src/sys/net/if.h:1.185 src/sys/net/if.h:1.186
--- src/sys/net/if.h:1.185	Fri Jan 16 10:37:51 2015
+++ src/sys/net/if.h	Fri Apr  3 08:20:55 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: if.h,v 1.185 2015/01/16 10:37:51 ozaki-r Exp $	*/
+/*	$NetBSD: if.h,v 1.186 2015/04/03 08:20:55 msaitoh Exp $	*/
 
 /*-
  * Copyright (c) 1999, 2000, 2001 The NetBSD Foundation, Inc.
@@ -396,11 +396,10 @@ typedef struct ifnet {
 
 /*
  * Some convenience macros used for setting ifi_baudrate.
- * XXX 1000 vs. 1024? --thor...@netbsd.org
  */
-#define	IF_Kbps(x)	((x) * 1000)		/* kilobits/sec. */
-#define	IF_Mbps(x)	(IF_Kbps((x) * 1000))	/* megabits/sec. */
-#define	IF_Gbps(x)	(IF_Mbps((x) * 1000))	/* gigabits/sec. */
+#define	IF_Kbps(x)	((x) * 1000ULL)			/* kilobits/sec. */
+#define	IF_Mbps(x)	(IF_Kbps((x) * 1000ULL))	/* megabits/sec. */
+#define	IF_Gbps(x)	(IF_Mbps((x) * 1000ULL))	/* gigabits/sec. */
 
 /* Capabilities that interfaces can advertise. */
 	/* 0x01 .. 0x40 were previously used */



CVS commit: src/sys/arch/sparc64/include

2015-04-03 Thread Palle Lyckegaard
Module Name:src
Committed By:   palle
Date:   Fri Apr  3 10:07:57 UTC 2015

Modified Files:
src/sys/arch/sparc64/include: pte.h

Log Message:
sun4v: There is no L-bit (Locked) in the sun4v tte


To generate a diff of this commit:
cvs rdiff -u -r1.26 -r1.27 src/sys/arch/sparc64/include/pte.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/sparc64/include/pte.h
diff -u src/sys/arch/sparc64/include/pte.h:1.26 src/sys/arch/sparc64/include/pte.h:1.27
--- src/sys/arch/sparc64/include/pte.h:1.26	Mon Mar  3 05:05:09 2014
+++ src/sys/arch/sparc64/include/pte.h	Fri Apr  3 10:07:57 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: pte.h,v 1.26 2014/03/03 05:05:09 palle Exp $ */
+/*	$NetBSD: pte.h,v 1.27 2015/04/03 10:07:57 palle Exp $ */
 
 /*
  * Copyright (c) 1996-1999 Eduardo Horvath
@@ -242,7 +242,6 @@ typedef struct sun4u_tte pte_t;
 #define SUN4V_TLB_MODIFY	0x0020LL
 #define SUN4V_TLB_REAL_W	0x2000LL
 #define SUN4V_TLB_TSB_LOCK	0x1000LL
-#define SUN4V_TLB_L SUN4V_TLB_TSB_LOCK 
 #define SUN4V_TLB_EXEC		SUN4V_TLB_X
 #define SUN4V_TLB_EXEC_ONLY	0x0200LL
 /* H/W bits */
@@ -282,7 +281,7 @@ typedef struct sun4u_tte pte_t;
 #define TLB_REAL_W(CPU_ISSUN4V ? SUN4V_TLB_REAL_W: SUN4U_TLB_REAL_W)
 #define TLB_TSB_LOCK  (CPU_ISSUN4V ? SUN4V_TLB_TSB_LOCK  : SUN4U_TLB_TSB_LOCK)
 #define TLB_EXEC_ONLY (CPU_ISSUN4V ? SUN4V_TLB_EXEC_ONLY : SUN4U_TLB_EXEC_ONLY)
-#define TLB_L (CPU_ISSUN4V ? SUN4V_TLB_L : SUN4U_TLB_L)
+#define TLB_L (CPU_ISSUN4V ? 0   : SUN4U_TLB_L)
 #define TLB_CV(CPU_ISSUN4V ? SUN4V_TLB_CV: SUN4U_TLB_CV)
 
 #define MMU_CACHE_VIRT	0x3



CVS commit: src/sys/rump/net/lib/libnet/opt

2015-04-03 Thread Ryota Ozaki
Module Name:src
Committed By:   ozaki-r
Date:   Fri Apr  3 07:56:54 UTC 2015

Added Files:
src/sys/rump/net/lib/libnet/opt: opt_net_mpsafe.h

Log Message:
Add opt_net_mpsafe.h for rump


To generate a diff of this commit:
cvs rdiff -u -r0 -r1.1 src/sys/rump/net/lib/libnet/opt/opt_net_mpsafe.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Added files:

Index: src/sys/rump/net/lib/libnet/opt/opt_net_mpsafe.h
diff -u /dev/null src/sys/rump/net/lib/libnet/opt/opt_net_mpsafe.h:1.1
--- /dev/null	Fri Apr  3 07:56:54 2015
+++ src/sys/rump/net/lib/libnet/opt/opt_net_mpsafe.h	Fri Apr  3 07:56:54 2015
@@ -0,0 +1,3 @@
+/*	$NetBSD: opt_net_mpsafe.h,v 1.1 2015/04/03 07:56:54 ozaki-r Exp $	*/
+
+/* dummy */



CVS commit: src/usr.sbin/sysinst

2015-04-03 Thread Marc Balmer
Module Name:src
Committed By:   mbalmer
Date:   Fri Apr  3 14:57:41 UTC 2015

Modified Files:
src/usr.sbin/sysinst: msg.mi.en msg.mi.pl

Log Message:
IPv4 number - IPv4 address


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 src/usr.sbin/sysinst/msg.mi.en \
src/usr.sbin/sysinst/msg.mi.pl

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.sbin/sysinst/msg.mi.en
diff -u src/usr.sbin/sysinst/msg.mi.en:1.6 src/usr.sbin/sysinst/msg.mi.en:1.7
--- src/usr.sbin/sysinst/msg.mi.en:1.6	Mon Nov 10 01:05:10 2014
+++ src/usr.sbin/sysinst/msg.mi.en	Fri Apr  3 14:57:41 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: msg.mi.en,v 1.6 2014/11/10 01:05:10 snj Exp $	*/
+/*	$NetBSD: msg.mi.en,v 1.7 2015/04/03 14:57:41 mbalmer Exp $	*/
 
 /*
  * Copyright 1997 Piermont Information Systems Inc.
@@ -521,10 +521,10 @@ message net_host
 {Your host name}
 
 message net_ip
-{Your IPv4 number}
+{Your IPv4 address}
 
 message net_srv_ip
-{Server IPv4 number}
+{Server IPv4 address}
 
 message net_mask
 {IPv4 Netmask}
Index: src/usr.sbin/sysinst/msg.mi.pl
diff -u src/usr.sbin/sysinst/msg.mi.pl:1.6 src/usr.sbin/sysinst/msg.mi.pl:1.7
--- src/usr.sbin/sysinst/msg.mi.pl:1.6	Mon Nov 10 01:05:10 2014
+++ src/usr.sbin/sysinst/msg.mi.pl	Fri Apr  3 14:57:41 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: msg.mi.pl,v 1.6 2014/11/10 01:05:10 snj Exp $	*/
+/*	$NetBSD: msg.mi.pl,v 1.7 2015/04/03 14:57:41 mbalmer Exp $	*/
 /*	Based on english version: */
 /*	NetBSD: msg.mi.pl,v 1.36 2004/04/17 18:55:35 atatat Exp   */
 
@@ -518,7 +518,7 @@ message net_ip
 {Twoj adres IPv4}
 
 message net_srv_ip
-{Server IPv4 number}
+{Server IPv4 address}
 
 message net_mask
 {Maska podsieci IPv4}



CVS commit: src/sys/rump/librump/rumpkern

2015-04-03 Thread Antti Kantee
Module Name:src
Committed By:   pooka
Date:   Fri Apr  3 16:37:02 UTC 2015

Modified Files:
src/sys/rump/librump/rumpkern: accessors.c

Log Message:
Use vmspace of calling [rump kernel] process instead of sysspace.


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/sys/rump/librump/rumpkern/accessors.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/rump/librump/rumpkern/accessors.c
diff -u src/sys/rump/librump/rumpkern/accessors.c:1.1 src/sys/rump/librump/rumpkern/accessors.c:1.2
--- src/sys/rump/librump/rumpkern/accessors.c:1.1	Fri Apr 25 18:25:38 2014
+++ src/sys/rump/librump/rumpkern/accessors.c	Fri Apr  3 16:37:02 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: accessors.c,v 1.1 2014/04/25 18:25:38 pooka Exp $	*/
+/*	$NetBSD: accessors.c,v 1.2 2015/04/03 16:37:02 pooka Exp $	*/
 
 /*
  * Copyright (c) 2007-2011 Antti Kantee.  All Rights Reserved.
@@ -32,7 +32,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: accessors.c,v 1.1 2014/04/25 18:25:38 pooka Exp $);
+__KERNEL_RCSID(0, $NetBSD: accessors.c,v 1.2 2015/04/03 16:37:02 pooka Exp $);
 
 #include sys/param.h
 #include sys/kauth.h
@@ -68,7 +68,7 @@ rump_uio_setup(void *buf, size_t bufsize
 	uio-uio_offset = offset;
 	uio-uio_resid = bufsize;
 	uio-uio_rw = uiorw;
-	UIO_SETUP_SYSSPACE(uio);
+	uio-uio_vmspace = curproc-p_vmspace;
 
 	return uio;
 }



CVS commit: src/external/gpl3/gcc/dist/gcc/config

2015-04-03 Thread Manuel Bouyer
Module Name:src
Committed By:   bouyer
Date:   Fri Apr  3 17:25:43 UTC 2015

Modified Files:
src/external/gpl3/gcc/dist/gcc/config: host-netbsd.c

Log Message:
Use the same TRY_EMPTY_VM_SPACE as mips and vax for arm, which also
has VM_MAXUSER_ADDRESS set to 2GB. Fixes fatal error: had to relocate PCH
from g++ building wxGTK28 or wxGTK30.
For details see https://gcc.gnu.org/bugzilla/show_bug.cgi?id=58379

thanks to Martin Husemann for the hint.


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/external/gpl3/gcc/dist/gcc/config/host-netbsd.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/gpl3/gcc/dist/gcc/config/host-netbsd.c
diff -u src/external/gpl3/gcc/dist/gcc/config/host-netbsd.c:1.1 src/external/gpl3/gcc/dist/gcc/config/host-netbsd.c:1.2
--- src/external/gpl3/gcc/dist/gcc/config/host-netbsd.c:1.1	Sat Mar  1 09:26:00 2014
+++ src/external/gpl3/gcc/dist/gcc/config/host-netbsd.c	Fri Apr  3 17:25:42 2015
@@ -35,7 +35,7 @@
 # define TRY_EMPTY_VM_SPACE	0x400
 #elif defined(_LP64)
 # define TRY_EMPTY_VM_SPACE	0x4000
-#elif defined(__mips__) || defined(__vax__)
+#elif defined(__mips__) || defined(__vax__) || defined (__arm__)
 # define TRY_EMPTY_VM_SPACE	0x6000
 #else
 # define TRY_EMPTY_VM_SPACE	0xb000



CVS commit: src/sys/arch

2015-04-03 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Fri Apr  3 18:03:05 UTC 2015

Modified Files:
src/sys/arch/arm/amlogic: amlogic_genfb.c amlogic_vpureg.h
src/sys/arch/evbarm/amlogic: amlogic_machdep.c

Log Message:
Allow for choosing between 16 and 24bpp framebuffers. The default is now
16 instead of 24. Set 'fb.depth=16' or 'fb.depth=24' on kernel command-line
to explicitly select a colour depth.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/sys/arch/arm/amlogic/amlogic_genfb.c
cvs rdiff -u -r1.2 -r1.3 src/sys/arch/arm/amlogic/amlogic_vpureg.h
cvs rdiff -u -r1.19 -r1.20 src/sys/arch/evbarm/amlogic/amlogic_machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/amlogic/amlogic_genfb.c
diff -u src/sys/arch/arm/amlogic/amlogic_genfb.c:1.4 src/sys/arch/arm/amlogic/amlogic_genfb.c:1.5
--- src/sys/arch/arm/amlogic/amlogic_genfb.c:1.4	Thu Mar 26 16:26:35 2015
+++ src/sys/arch/arm/amlogic/amlogic_genfb.c	Fri Apr  3 18:03:05 2015
@@ -1,4 +1,4 @@
-/* $NetBSD: amlogic_genfb.c,v 1.4 2015/03/26 16:26:35 joerg Exp $ */
+/* $NetBSD: amlogic_genfb.c,v 1.5 2015/04/03 18:03:05 jmcneill Exp $ */
 
 /*-
  * Copyright (c) 2015 Jared D. McNeill jmcne...@invisible.ca
@@ -31,7 +31,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: amlogic_genfb.c,v 1.4 2015/03/26 16:26:35 joerg Exp $);
+__KERNEL_RCSID(0, $NetBSD: amlogic_genfb.c,v 1.5 2015/04/03 18:03:05 jmcneill Exp $);
 
 #include sys/param.h
 #include sys/types.h
@@ -50,6 +50,8 @@ __KERNEL_RCSID(0, $NetBSD: amlogic_genf
 
 #include dev/wsfb/genfbvar.h
 
+#define AMLOGIC_GENFB_DEFAULT_DEPTH	16
+
 /* Map CEA-861-D video code (VIC) to framebuffer dimensions */
 static const struct amlogic_genfb_vic2mode {
 	u_int vic;
@@ -268,12 +270,13 @@ amlogic_genfb_canvas_config(struct amlog
 	prop_dictionary_t cfg = device_properties(sc-sc_gen.sc_dev);
 	const paddr_t pa = sc-sc_dmamap-dm_segs[0].ds_addr;
 	uint32_t datal, datah, addr;
-	u_int width, height;
+	u_int width, height, depth;
 
 	prop_dictionary_get_uint32(cfg, width, width);
 	prop_dictionary_get_uint32(cfg, height, height);
+	prop_dictionary_get_uint32(cfg, depth, depth);
 
-	const uint32_t w = (width * 3)  3;
+	const uint32_t w = (width * (depth/8))  3;
 	const uint32_t h = height;
 
 	datal = CAV_READ(sc, DC_CAV_LUT_DATAL_REG);
@@ -303,17 +306,56 @@ static void
 amlogic_genfb_osd_config(struct amlogic_genfb_softc *sc)
 {
 	prop_dictionary_t cfg = device_properties(sc-sc_gen.sc_dev);
-	uint32_t w0, w1, w2, w3, w4;
-	u_int width, height;
+	uint32_t cs, tc, w0, w1, w2, w3, w4;
+	u_int width, height, depth;
 	bool interlace_p;
 
 	prop_dictionary_get_uint32(cfg, width, width);
 	prop_dictionary_get_uint32(cfg, height, height);
+	prop_dictionary_get_uint32(cfg, depth, depth);
 	prop_dictionary_get_bool(cfg, interlace, interlace_p);
 
+	cs = VPU_READ(sc, VIU_OSD2_CTRL_STAT_REG);
+	cs |= VIU_OSD_CTRL_STAT_ENABLE;
+	cs = ~VIU_OSD_CTRL_STAT_GLOBAL_ALPHA;
+	cs |= __SHIFTIN(0xff, VIU_OSD_CTRL_STAT_GLOBAL_ALPHA);
+	cs |= VIU_OSD_CTRL_STAT_BLK0_ENABLE;
+	cs = ~VIU_OSD_CTRL_STAT_BLK1_ENABLE;
+	cs = ~VIU_OSD_CTRL_STAT_BLK2_ENABLE;
+	cs = ~VIU_OSD_CTRL_STAT_BLK3_ENABLE;
+	VPU_WRITE(sc, VIU_OSD2_CTRL_STAT_REG, cs);
+
+	tc = __SHIFTIN(0, VIU_OSD_TCOLOR_R) |
+	 __SHIFTIN(0, VIU_OSD_TCOLOR_G) |
+	 __SHIFTIN(0, VIU_OSD_TCOLOR_B) |
+	 __SHIFTIN(255, VIU_OSD_TCOLOR_A);
+	VPU_WRITE(sc, VIU_OSD2_TCOLOR_AG0_REG, tc);
+
 	w0 = VPU_READ(sc, VIU_OSD2_BLK0_CFG_W0_REG);
+	w0 |= VIU_OSD_BLK_CFG_W0_RGB_EN;
+	w0 = ~VIU_OSD_BLK_CFG_W0_TC_ALPHA_EN;
 	w0 = ~VIU_OSD_BLK_CFG_W0_OSD_BLK_MODE;
-	w0 |= __SHIFTIN(7, VIU_OSD_BLK_CFG_W0_OSD_BLK_MODE);
+	w0 = ~VIU_OSD_BLK_CFG_W0_COLOR_MATRIX;
+	switch (depth) {
+	case 32:
+		w0 |= __SHIFTIN(VIU_OSD_BLK_CFG_W0_OSD_BLK_MODE_32BPP,
+VIU_OSD_BLK_CFG_W0_OSD_BLK_MODE);
+		w0 |= __SHIFTIN(VIU_OSD_BLK_CFG_W0_COLOR_MATRIX_ARGB,
+VIU_OSD_BLK_CFG_W0_COLOR_MATRIX);
+		break;
+	case 24:
+		w0 |= __SHIFTIN(VIU_OSD_BLK_CFG_W0_OSD_BLK_MODE_24BPP,
+VIU_OSD_BLK_CFG_W0_OSD_BLK_MODE);
+		w0 |= __SHIFTIN(VIU_OSD_BLK_CFG_W0_COLOR_MATRIX_RGB,
+VIU_OSD_BLK_CFG_W0_COLOR_MATRIX);
+		break;
+	case 16:
+		w0 |= __SHIFTIN(VIU_OSD_BLK_CFG_W0_OSD_BLK_MODE_16BPP,
+VIU_OSD_BLK_CFG_W0_OSD_BLK_MODE);
+		w0 |= __SHIFTIN(VIU_OSD_BLK_CFG_W0_COLOR_MATRIX_RGB565,
+VIU_OSD_BLK_CFG_W0_COLOR_MATRIX);
+		break;
+	}
 	w0 |= VIU_OSD_BLK_CFG_W0_LITTLE_ENDIAN;
 	w0 = ~VIU_OSD_BLK_CFG_W0_RPT_Y;
 	w0 = ~VIU_OSD_BLK_CFG_W0_INTERP_CTRL;
@@ -322,8 +364,6 @@ amlogic_genfb_osd_config(struct amlogic_
 	} else {
 		w0 = ~VIU_OSD_BLK_CFG_W0_INTERLACE_EN;
 	}
-	w0 |= VIU_OSD_BLK_CFG_W0_RGB_EN;
-	w0 = ~VIU_OSD_BLK_CFG_W0_COLOR_MATRIX;
 	VPU_WRITE(sc, VIU_OSD2_BLK0_CFG_W0_REG, w0);
 
 	w1 = __SHIFTIN(width - 1, VIU_OSD_BLK_CFG_W1_X_END) |
@@ -456,7 +496,7 @@ amlogic_genfb_init(struct amlogic_genfb_
 {
 	prop_dictionary_t cfg = device_properties(sc-sc_gen.sc_dev);
 	const struct 

CVS commit: src/sys/rump

2015-04-03 Thread Antti Kantee
Module Name:src
Committed By:   pooka
Date:   Fri Apr  3 16:40:55 UTC 2015

Modified Files:
src/sys/rump/kern/lib/libsysproxy: sysproxy.c
src/sys/rump/librump/rumpkern: lwproc.c rump_private.h vm.c

Log Message:
Use a different vmspace for rump kernel proc0 and local clients.
While the rump kernel and local clients are by definition in the same
host vmspace, there are subtle differences in how in-kernel code works
in case accessing the kernel vmspace or a user process vmspace.

Problem discovered by riastradh's read(fd, NULL, 1) test.


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/sys/rump/kern/lib/libsysproxy/sysproxy.c
cvs rdiff -u -r1.32 -r1.33 src/sys/rump/librump/rumpkern/lwproc.c
cvs rdiff -u -r1.87 -r1.88 src/sys/rump/librump/rumpkern/rump_private.h
cvs rdiff -u -r1.161 -r1.162 src/sys/rump/librump/rumpkern/vm.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/rump/kern/lib/libsysproxy/sysproxy.c
diff -u src/sys/rump/kern/lib/libsysproxy/sysproxy.c:1.1 src/sys/rump/kern/lib/libsysproxy/sysproxy.c:1.2
--- src/sys/rump/kern/lib/libsysproxy/sysproxy.c:1.1	Wed Jan  7 22:24:04 2015
+++ src/sys/rump/kern/lib/libsysproxy/sysproxy.c	Fri Apr  3 16:40:55 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: sysproxy.c,v 1.1 2015/01/07 22:24:04 pooka Exp $	*/
+/*	$NetBSD: sysproxy.c,v 1.2 2015/04/03 16:40:55 pooka Exp $	*/
 
 /*
  * Copyright (c) 2010, 2011 Antti Kantee.  All Rights Reserved.
@@ -26,7 +26,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: sysproxy.c,v 1.1 2015/01/07 22:24:04 pooka Exp $);
+__KERNEL_RCSID(0, $NetBSD: sysproxy.c,v 1.2 2015/04/03 16:40:55 pooka Exp $);
 
 #include sys/param.h
 #include sys/filedesc.h
@@ -79,7 +79,7 @@ hyp_syscall(int num, void *arg, long *re
 static int
 hyp_rfork(void *priv, int flags, const char *comm)
 {
-	struct vmspace *newspace;
+	struct vmspace *vm;
 	struct proc *p;
 	struct lwp *l;
 	int error;
@@ -96,8 +96,16 @@ hyp_rfork(void *priv, int flags, const c
 		initfds = false;
 	}
 
-	if ((error = rump_lwproc_rfork(flags)) != 0)
+	/*
+	 * Since it's a proxy proc, we need create a vmspace for it.
+	 */
+	vm = kmem_zalloc(sizeof(*vm), KM_SLEEP);
+	uvmspace_init(vm, priv, 0, 0, false);
+
+	if ((error = rump_lwproc_rfork_vmspace(vm, flags)) != 0) {
+		kmem_free(vm, sizeof(*vm));
 		return error;
+	}
 
 	/*
 	 * We forked in this routine, so cannot use curlwp (const)
@@ -105,15 +113,6 @@ hyp_rfork(void *priv, int flags, const c
 	l = rump_lwproc_curlwp();
 	p = l-l_proc;
 
-	/*
-	 * Since it's a proxy proc, adjust the vmspace.
-	 * Refcount will eternally be 1.
-	 */
-	newspace = kmem_zalloc(sizeof(*newspace), KM_SLEEP);
-	newspace-vm_refcnt = 1;
-	newspace-vm_map.pmap = priv;
-	KASSERT(p-p_vmspace == vmspace_kernel());
-	p-p_vmspace = newspace;
 	if (comm)
 		strlcpy(p-p_comm, comm, sizeof(p-p_comm));
 	if (initfds)

Index: src/sys/rump/librump/rumpkern/rump_private.h
diff -u src/sys/rump/librump/rumpkern/rump_private.h:1.88 src/sys/rump/librump/rumpkern/rump_private.h:1.89
--- src/sys/rump/librump/rumpkern/rump_private.h:1.88	Fri Apr  3 16:40:55 2015
+++ src/sys/rump/librump/rumpkern/rump_private.h	Fri Apr  3 16:46:39 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: rump_private.h,v 1.88 2015/04/03 16:40:55 pooka Exp $	*/
+/*	$NetBSD: rump_private.h,v 1.89 2015/04/03 16:46:39 pooka Exp $	*/
 
 /*
  * Copyright (c) 2007-2011 Antti Kantee.  All Rights Reserved.
@@ -120,6 +120,8 @@ extern unsigned long rump_physmemlimit;
 extern struct vmspace *rump_vmspace_local;
 #define RUMP_LOCALPROC_P(p) \
 (p-p_vmspace == vmspace_kernel() || p-p_vmspace == rump_vmspace_local)
+#define RUMP_PMAP_KERNEL ((struct pmap *const)-1)
+#define RUMP_PMAP_LOCAL ((struct pmap *)-2)
 
 void		rump_component_load(const struct rump_component *);
 void		rump_component_init(enum rump_component_type);

Index: src/sys/rump/librump/rumpkern/vm.c
diff -u src/sys/rump/librump/rumpkern/vm.c:1.162 src/sys/rump/librump/rumpkern/vm.c:1.163
--- src/sys/rump/librump/rumpkern/vm.c:1.162	Fri Apr  3 16:40:55 2015
+++ src/sys/rump/librump/rumpkern/vm.c	Fri Apr  3 16:46:39 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: vm.c,v 1.162 2015/04/03 16:40:55 pooka Exp $	*/
+/*	$NetBSD: vm.c,v 1.163 2015/04/03 16:46:39 pooka Exp $	*/
 
 /*
  * Copyright (c) 2007-2011 Antti Kantee.  All Rights Reserved.
@@ -41,7 +41,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: vm.c,v 1.162 2015/04/03 16:40:55 pooka Exp $);
+__KERNEL_RCSID(0, $NetBSD: vm.c,v 1.163 2015/04/03 16:46:39 pooka Exp $);
 
 #include sys/param.h
 #include sys/atomic.h
@@ -395,7 +395,7 @@ uvm_init(void)
 
 	/* create vmspace used by local clients */
 	rump_vmspace_local = kmem_zalloc(sizeof(*rump_vmspace_local), KM_SLEEP);
-	uvmspace_init(rump_vmspace_local, (struct pmap *)-2, 0, 0, false);
+	uvmspace_init(rump_vmspace_local, RUMP_PMAP_LOCAL, 0, 0, false);
 }
 
 void

Index: src/sys/rump/librump/rumpkern/arch/generic/rump_generic_pmap.c
diff -u src/sys/rump/librump/rumpkern/arch/generic/rump_generic_pmap.c:1.2 src/sys/rump/librump/rumpkern/arch/generic/rump_generic_pmap.c:1.3
--- src/sys/rump/librump/rumpkern/arch/generic/rump_generic_pmap.c:1.2	Wed Feb 12 22:30:45 2014
+++ src/sys/rump/librump/rumpkern/arch/generic/rump_generic_pmap.c	Fri Apr  3 16:46:39 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: rump_generic_pmap.c,v 1.2 2014/02/12 22:30:45 pooka Exp $	*/
+/*	$NetBSD: rump_generic_pmap.c,v 1.3 2015/04/03 16:46:39 pooka Exp $	*/
 
 /*
  * Copyright (c) 2010 Antti Kantee.  All Rights Reserved.
@@ -26,18 +26,20 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: rump_generic_pmap.c,v 1.2 2014/02/12 22:30:45 pooka Exp $);
+__KERNEL_RCSID(0, $NetBSD: rump_generic_pmap.c,v 1.3 2015/04/03 16:46:39 pooka Exp $);
 
 #include sys/param.h
 
 #include uvm/uvm_extern.h
 
+#include rump_private.h
+
 /*
  * This is the MI pmap implementation for rump kernels.  It's used only by
  * architectures which do not conform to the kernel ABI.
  */
 
-struct pmap *const kernel_pmap_ptr = (struct pmap *const)-1;
+struct pmap *const kernel_pmap_ptr = RUMP_PMAP_KERNEL;
 
 void
 pmap_kenter_pa(vaddr_t va, paddr_t pa, vm_prot_t prot, u_int fl)

Index: src/sys/rump/librump/rumpkern/arch/x86/rump_x86_pmap.c
diff -u src/sys/rump/librump/rumpkern/arch/x86/rump_x86_pmap.c:1.1 src/sys/rump/librump/rumpkern/arch/x86/rump_x86_pmap.c:1.2
--- src/sys/rump/librump/rumpkern/arch/x86/rump_x86_pmap.c:1.1	Wed Feb 12 22:28:43 2014
+++ src/sys/rump/librump/rumpkern/arch/x86/rump_x86_pmap.c	Fri Apr  3 16:46:39 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: rump_x86_pmap.c,v 1.1 2014/02/12 22:28:43 pooka Exp $	*/
+/*	$NetBSD: rump_x86_pmap.c,v 1.2 2015/04/03 16:46:39 pooka Exp $	*/
 
 /*
  * Copyright (c) 2010 Antti Kantee.  All Rights Reserved.
@@ -26,14 +26,15 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: rump_x86_pmap.c,v 1.1 2014/02/12 22:28:43 pooka Exp $);
+__KERNEL_RCSID(0, $NetBSD: rump_x86_pmap.c,v 1.2 2015/04/03 16:46:39 pooka Exp $);
 
 #include sys/param.h
 
 #include 

CVS commit: src/sys/arch/evbarm/conf

2015-04-03 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Fri Apr  3 18:00:25 UTC 2015

Modified Files:
src/sys/arch/evbarm/conf: ODROID-C1

Log Message:
comment out DDB_COMMANDONENTER


To generate a diff of this commit:
cvs rdiff -u -r1.14 -r1.15 src/sys/arch/evbarm/conf/ODROID-C1

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/conf/ODROID-C1
diff -u src/sys/arch/evbarm/conf/ODROID-C1:1.14 src/sys/arch/evbarm/conf/ODROID-C1:1.15
--- src/sys/arch/evbarm/conf/ODROID-C1:1.14	Tue Mar 31 17:37:47 2015
+++ src/sys/arch/evbarm/conf/ODROID-C1	Fri Apr  3 18:00:25 2015
@@ -1,5 +1,5 @@
 #
-#	$NetBSD: ODROID-C1,v 1.14 2015/03/31 17:37:47 riz Exp $
+#	$NetBSD: ODROID-C1,v 1.15 2015/04/03 18:00:25 jmcneill Exp $
 #
 #	Odroid-C1 (Amlogic S805) based SBC (Single Board Computer)
 #
@@ -143,7 +143,7 @@ options 	DIAGNOSTIC	# internal consisten
 options 	DDB		# in-kernel debugger
 options		DDB_ONPANIC=1
 options 	DDB_HISTORY_SIZE=100	# Enable history editing in DDB
-options		DDB_COMMANDONENTER=bt
+#options 	DDB_COMMANDONENTER=bt
 #options 	KGDB
 makeoptions	DEBUG=-g	# compile full symbol table
 makeoptions	COPY_SYMTAB=1



CVS commit: src/distrib/sets/lists/tests

2015-04-03 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Apr  3 21:38:47 UTC 2015

Modified Files:
src/distrib/sets/lists/tests: mi

Log Message:
add another lint test


To generate a diff of this commit:
cvs rdiff -u -r1.613 -r1.614 src/distrib/sets/lists/tests/mi

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/tests/mi
diff -u src/distrib/sets/lists/tests/mi:1.613 src/distrib/sets/lists/tests/mi:1.614
--- src/distrib/sets/lists/tests/mi:1.613	Sun Mar 29 15:37:02 2015
+++ src/distrib/sets/lists/tests/mi	Fri Apr  3 17:38:47 2015
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.613 2015/03/29 19:37:02 chopps Exp $
+# $NetBSD: mi,v 1.614 2015/04/03 21:38:47 christos Exp $
 #
 # Note: don't delete entries from here - mark them as obsolete instead.
 #
@@ -3762,6 +3762,7 @@
 ./usr/tests/usr.bin/xlint/lint1/d_type_conv1.c			tests-usr.bin-tests	atf
 ./usr/tests/usr.bin/xlint/lint1/d_type_conv2.c			tests-usr.bin-tests	atf
 ./usr/tests/usr.bin/xlint/lint1/d_type_conv3.c			tests-usr.bin-tests	atf
+./usr/tests/usr.bin/xlint/lint1/d_typefun.c			tests-usr.bin-tests	atf
 ./usr/tests/usr.bin/xlint/lint1/d_typename_as_var.c		tests-usr.bin-tests	atf
 ./usr/tests/usr.bin/xlint/lint1/d_zero_sized_arrays.c		tests-usr.bin-tests	atf
 ./usr/tests/usr.bin/xlint/lint1/t_integration			tests-usr.bin-tests	atf



CVS commit: src/usr.bin/xlint/lint1

2015-04-03 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Apr  3 21:40:04 UTC 2015

Modified Files:
src/usr.bin/xlint/lint1: cgram.y

Log Message:
accept typenames in param decls.


To generate a diff of this commit:
cvs rdiff -u -r1.67 -r1.68 src/usr.bin/xlint/lint1/cgram.y

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/xlint/lint1/cgram.y
diff -u src/usr.bin/xlint/lint1/cgram.y:1.67 src/usr.bin/xlint/lint1/cgram.y:1.68
--- src/usr.bin/xlint/lint1/cgram.y:1.67	Fri Sep 26 11:26:01 2014
+++ src/usr.bin/xlint/lint1/cgram.y	Fri Apr  3 17:40:04 2015
@@ -1,5 +1,5 @@
 %{
-/* $NetBSD: cgram.y,v 1.67 2014/09/26 15:26:01 christos Exp $ */
+/* $NetBSD: cgram.y,v 1.68 2015/04/03 21:40:04 christos Exp $ */
 
 /*
  * Copyright (c) 1996 Christopher G. Demetriou.  All Rights Reserved.
@@ -35,7 +35,7 @@
 
 #include sys/cdefs.h
 #if defined(__RCSID)  !defined(lint)
-__RCSID($NetBSD: cgram.y,v 1.67 2014/09/26 15:26:01 christos Exp $);
+__RCSID($NetBSD: cgram.y,v 1.68 2015/04/03 21:40:04 christos Exp $);
 #endif
 
 #include stdlib.h
@@ -107,7 +107,7 @@ static inline void RESTORE(const char *f
 #endif
 %}
 
-%expect 75
+%expect 78
 
 %union {
 	int	y_int;
@@ -1025,7 +1025,7 @@ notype_param_decl:
 	;
 
 direct_notype_param_decl:
-	  T_NAME {
+	  identifier {
 		$$ = dname(getsym($1));
 	  }
 	| T_LPARN notype_param_decl T_RPARN {



CVS commit: src/tests/usr.bin/xlint/lint1

2015-04-03 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Apr  3 21:37:26 UTC 2015

Modified Files:
src/tests/usr.bin/xlint/lint1: Makefile
Added Files:
src/tests/usr.bin/xlint/lint1: d_typefun.c

Log Message:
add test for typename as a function param


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/tests/usr.bin/xlint/lint1/Makefile
cvs rdiff -u -r0 -r1.1 src/tests/usr.bin/xlint/lint1/d_typefun.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/tests/usr.bin/xlint/lint1/Makefile
diff -u src/tests/usr.bin/xlint/lint1/Makefile:1.5 src/tests/usr.bin/xlint/lint1/Makefile:1.6
--- src/tests/usr.bin/xlint/lint1/Makefile:1.5	Thu Nov 20 16:18:47 2014
+++ src/tests/usr.bin/xlint/lint1/Makefile	Fri Apr  3 17:37:26 2015
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.5 2014/11/20 21:18:47 christos Exp $
+# $NetBSD: Makefile,v 1.6 2015/04/03 21:37:26 christos Exp $
 
 NOMAN=		# defined
 
@@ -52,6 +52,7 @@ FILES+=		d_type_conv1.c
 FILES+=		d_type_conv2.c
 FILES+=		d_type_conv3.c
 FILES+=		d_typename_as_var.c
+FILES+=		d_typefun.c
 FILES+=		d_zero_sized_arrays.c
 
 .include bsd.test.mk

Added files:

Index: src/tests/usr.bin/xlint/lint1/d_typefun.c
diff -u /dev/null src/tests/usr.bin/xlint/lint1/d_typefun.c:1.1
--- /dev/null	Fri Apr  3 17:37:26 2015
+++ src/tests/usr.bin/xlint/lint1/d_typefun.c	Fri Apr  3 17:37:26 2015
@@ -0,0 +1,22 @@
+/* typedef of function parameter */
+
+typedef void (*free_func) (void * opaque, void* address);
+typedef struct stack_st
+{
+ int num;
+ char **data;
+ int sorted;
+
+ int num_alloc;
+ int (*comp)(const void *, const void *);
+} _STACK; /* Use STACK_OF(...) instead */
+
+typedef void *OPENSSL_BLOCK;
+struct stack_st_OPENSSL_BLOCK { _STACK stack; };
+typedef void *d2i_of_void(void **,const unsigned char **,long); typedef int i2d_of_void(void *,unsigned char **);
+
+struct stack_st_OPENSSL_BLOCK *d2i_ASN1_SET(struct stack_st_OPENSSL_BLOCK **a,
+ const unsigned char **pp,
+ long length, d2i_of_void *d2i,
+ void (*free_func)(OPENSSL_BLOCK), int ex_tag,
+ int ex_class);



CVS commit: src/sys

2015-04-03 Thread Tyler R. Retzlaff
Module Name:src
Committed By:   rtr
Date:   Fri Apr  3 20:01:08 UTC 2015

Modified Files:
src/sys/compat/linux/common: linux_socket.c
src/sys/compat/svr4: svr4_stream.c
src/sys/kern: uipc_socket.c uipc_syscalls.c uipc_usrreq.c
src/sys/net: if_gre.c link_proto.c rtsock.c
src/sys/netatalk: ddp_usrreq.c
src/sys/netbt: hci_socket.c l2cap_socket.c rfcomm_socket.c sco_socket.c
src/sys/netinet: in_pcb.c in_pcb.h raw_ip.c tcp_usrreq.c udp_usrreq.c
src/sys/netinet6: in6_pcb.c in6_pcb.h raw_ip6.c udp6_usrreq.c
src/sys/netipsec: keysock.c
src/sys/netmpls: mpls_proto.c
src/sys/netnatm: natm.c
src/sys/nfs: nfs_boot.c nfs_socket.c
src/sys/rump/net/lib/libsockin: sockin.c
src/sys/sys: param.h protosw.h socket.h socketvar.h

Log Message:
* change pr_bind to accept struct sockaddr * instead of struct mbuf *
* update protocol bind implementations to use/expect sockaddr *
  instead of mbuf *
* introduce sockaddr_big struct for storage of addr data passed via
  sys_bind; sockaddr_big is of sufficient size and alignment to
  accommodate all addr data sizes received.
* modify sys_bind to allocate sockaddr_big instead of using an mbuf.
* bump kernel version to 7.99.9 for change to pr_bind() parameter type.

Patch posted to tech-net@
  http://mail-index.netbsd.org/tech-net/2015/03/15/msg005004.html

The choice to use a new structure sockaddr_big has been retained since
changing sockaddr_storage size would lead to unnecessary ABI change. The
use of the new structure does not preclude future work that increases
the size of sockaddr_storage and at that time sockaddr_big may be
trivially replaced.

Tested by mrg@ and myself, discussed with rmind@, posted to tech-net@


To generate a diff of this commit:
cvs rdiff -u -r1.122 -r1.123 src/sys/compat/linux/common/linux_socket.c
cvs rdiff -u -r1.81 -r1.82 src/sys/compat/svr4/svr4_stream.c
cvs rdiff -u -r1.235 -r1.236 src/sys/kern/uipc_socket.c
cvs rdiff -u -r1.174 -r1.175 src/sys/kern/uipc_syscalls.c
cvs rdiff -u -r1.175 -r1.176 src/sys/kern/uipc_usrreq.c
cvs rdiff -u -r1.161 -r1.162 src/sys/net/if_gre.c
cvs rdiff -u -r1.24 -r1.25 src/sys/net/link_proto.c
cvs rdiff -u -r1.166 -r1.167 src/sys/net/rtsock.c
cvs rdiff -u -r1.63 -r1.64 src/sys/netatalk/ddp_usrreq.c
cvs rdiff -u -r1.40 -r1.41 src/sys/netbt/hci_socket.c
cvs rdiff -u -r1.31 -r1.32 src/sys/netbt/l2cap_socket.c
cvs rdiff -u -r1.33 -r1.34 src/sys/netbt/rfcomm_socket.c \
src/sys/netbt/sco_socket.c
cvs rdiff -u -r1.155 -r1.156 src/sys/netinet/in_pcb.c
cvs rdiff -u -r1.55 -r1.56 src/sys/netinet/in_pcb.h
cvs rdiff -u -r1.146 -r1.147 src/sys/netinet/raw_ip.c
cvs rdiff -u -r1.204 -r1.205 src/sys/netinet/tcp_usrreq.c
cvs rdiff -u -r1.217 -r1.218 src/sys/netinet/udp_usrreq.c
cvs rdiff -u -r1.134 -r1.135 src/sys/netinet6/in6_pcb.c
cvs rdiff -u -r1.41 -r1.42 src/sys/netinet6/in6_pcb.h
cvs rdiff -u -r1.136 -r1.137 src/sys/netinet6/raw_ip6.c
cvs rdiff -u -r1.116 -r1.117 src/sys/netinet6/udp6_usrreq.c
cvs rdiff -u -r1.44 -r1.45 src/sys/netipsec/keysock.c
cvs rdiff -u -r1.24 -r1.25 src/sys/netmpls/mpls_proto.c
cvs rdiff -u -r1.45 -r1.46 src/sys/netnatm/natm.c
cvs rdiff -u -r1.82 -r1.83 src/sys/nfs/nfs_boot.c
cvs rdiff -u -r1.193 -r1.194 src/sys/nfs/nfs_socket.c
cvs rdiff -u -r1.58 -r1.59 src/sys/rump/net/lib/libsockin/sockin.c
cvs rdiff -u -r1.468 -r1.469 src/sys/sys/param.h
cvs rdiff -u -r1.60 -r1.61 src/sys/sys/protosw.h
cvs rdiff -u -r1.116 -r1.117 src/sys/sys/socket.h
cvs rdiff -u -r1.135 -r1.136 src/sys/sys/socketvar.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/compat/linux/common/linux_socket.c
diff -u src/sys/compat/linux/common/linux_socket.c:1.122 src/sys/compat/linux/common/linux_socket.c:1.123
--- src/sys/compat/linux/common/linux_socket.c:1.122	Wed Nov 26 09:53:53 2014
+++ src/sys/compat/linux/common/linux_socket.c	Fri Apr  3 20:01:07 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: linux_socket.c,v 1.122 2014/11/26 09:53:53 ozaki-r Exp $	*/
+/*	$NetBSD: linux_socket.c,v 1.123 2015/04/03 20:01:07 rtr Exp $	*/
 
 /*-
  * Copyright (c) 1995, 1998, 2008 The NetBSD Foundation, Inc.
@@ -35,7 +35,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: linux_socket.c,v 1.122 2014/11/26 09:53:53 ozaki-r Exp $);
+__KERNEL_RCSID(0, $NetBSD: linux_socket.c,v 1.123 2015/04/03 20:01:07 rtr Exp $);
 
 #if defined(_KERNEL_OPT)
 #include opt_inet.h
@@ -121,6 +121,8 @@ int linux_getifconf(struct lwp *, regist
 int linux_getifhwaddr(struct lwp *, register_t *, u_int, void *);
 static int linux_get_sa(struct lwp *, int, struct mbuf **,
 		const struct osockaddr *, unsigned int);
+static int linux_get_sa_sb(struct lwp *, int, struct sockaddr_big *,
+		const struct osockaddr *, socklen_t);
 static int linux_sa_put(struct osockaddr *osa);
 static int linux_to_bsd_msg_flags(int);
 static int bsd_to_linux_msg_flags(int);
@@ -1445,14 

CVS commit: [nick-nhusb] src/sys/dev/usb

2015-04-03 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Fri Apr  3 21:22:33 UTC 2015

Modified Files:
src/sys/dev/usb [nick-nhusb]: usb.c

Log Message:
Fix non-USB_DEBUG compile


To generate a diff of this commit:
cvs rdiff -u -r1.156.2.6 -r1.156.2.7 src/sys/dev/usb/usb.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/usb.c
diff -u src/sys/dev/usb/usb.c:1.156.2.6 src/sys/dev/usb/usb.c:1.156.2.7
--- src/sys/dev/usb/usb.c:1.156.2.6	Sat Mar 21 15:28:10 2015
+++ src/sys/dev/usb/usb.c	Fri Apr  3 21:22:33 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: usb.c,v 1.156.2.6 2015/03/21 15:28:10 skrll Exp $	*/
+/*	$NetBSD: usb.c,v 1.156.2.7 2015/04/03 21:22:33 skrll Exp $	*/
 
 /*
  * Copyright (c) 1998, 2002, 2008, 2012 The NetBSD Foundation, Inc.
@@ -37,7 +37,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: usb.c,v 1.156.2.6 2015/03/21 15:28:10 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: usb.c,v 1.156.2.7 2015/04/03 21:22:33 skrll Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_usb.h
@@ -119,6 +119,7 @@ SYSCTL_SETUP(sysctl_hw_usb_setup, sysct
 fail:
 	aprint_error(%s: sysctl_createv failed (err = %d)\n, __func__, err);
 }
+#else
 #define	usb_noexplore 0
 #endif
 



CVS commit: [nick-nhusb] src/sys/dev/usb

2015-04-03 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Fri Apr  3 21:33:23 UTC 2015

Modified Files:
src/sys/dev/usb [nick-nhusb]: uhci.c

Log Message:
Various readability changes.

#ifdef DIAGNOSTIC - KASSERT / __diagused


To generate a diff of this commit:
cvs rdiff -u -r1.264.4.30 -r1.264.4.31 src/sys/dev/usb/uhci.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/uhci.c
diff -u src/sys/dev/usb/uhci.c:1.264.4.30 src/sys/dev/usb/uhci.c:1.264.4.31
--- src/sys/dev/usb/uhci.c:1.264.4.30	Wed Apr  1 05:39:51 2015
+++ src/sys/dev/usb/uhci.c	Fri Apr  3 21:33:23 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: uhci.c,v 1.264.4.30 2015/04/01 05:39:51 skrll Exp $	*/
+/*	$NetBSD: uhci.c,v 1.264.4.31 2015/04/03 21:33:23 skrll Exp $	*/
 
 /*
  * Copyright (c) 1998, 2004, 2011, 2012 The NetBSD Foundation, Inc.
@@ -42,7 +42,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: uhci.c,v 1.264.4.30 2015/04/01 05:39:51 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: uhci.c,v 1.264.4.31 2015/04/03 21:33:23 skrll Exp $);
 
 #include opt_usb.h
 
@@ -621,9 +621,11 @@ uhci_allocx(struct usbd_bus *bus)
 	xfer = pool_cache_get(sc-sc_xferpool, PR_NOWAIT);
 	if (xfer != NULL) {
 		memset(xfer, 0, sizeof(struct uhci_xfer));
-		UXFER(xfer)-iinfo.sc = sc;
+
+		struct uhci_xfer *uxfer = UXFER(xfer);
+		uxfer-iinfo.sc = sc;
 #ifdef DIAGNOSTIC
-		UXFER(xfer)-iinfo.isdone = 1;
+		uxfer-iinfo.isdone = true;
 		xfer-ux_state = XFER_BUSY;
 #endif
 	}
@@ -634,16 +636,13 @@ void
 uhci_freex(struct usbd_bus *bus, struct usbd_xfer *xfer)
 {
 	struct uhci_softc *sc = bus-ub_hcpriv;
+	struct uhci_xfer *uxfer __diagused = UXFER(xfer);
 
+	KASSERTMSG(xfer-ux_state == XFER_BUSY, xfer %p state %d\n, xfer,
+	xfer-ux_state);
+	KASSERTMSG(uxfer-iinfo.isdone, xfer %p not done\n, xfer);
 #ifdef DIAGNOSTIC
-	if (xfer-ux_state != XFER_BUSY) {
-		printf(uhci_freex: xfer=%p not busy, 0x%08x\n, xfer,
-		   xfer-ux_state);
-	}
 	xfer-ux_state = XFER_FREE;
-	if (!UXFER(xfer)-iinfo.isdone) {
-		printf(uhci_freex: !isdone\n);
-	}
 #endif
 	pool_cache_put(sc-sc_xferpool, xfer);
 }
@@ -1402,12 +1401,9 @@ uhci_check_intr(uhci_softc_t *sc, uhci_i
 
 	UHCIHIST_FUNC(); UHCIHIST_CALLED();
 	DPRINTFN(15, ii %p, ii, 0, 0, 0);
-#ifdef DIAGNOSTIC
-	if (ii == NULL) {
-		printf(uhci_check_intr: no ii? %p\n, ii);
-		return;
-	}
-#endif
+
+	KASSERT(ii != NULL);
+
 	if (ii-xfer-ux_status == USBD_CANCELLED ||
 	ii-xfer-ux_status == USBD_TIMEOUT) {
 		DPRINTF(aborted xfer %p, ii-xfer, 0, 0, 0);
@@ -1417,12 +1413,9 @@ uhci_check_intr(uhci_softc_t *sc, uhci_i
 	if (ii-stdstart == NULL)
 		return;
 	lstd = ii-stdend;
-#ifdef DIAGNOSTIC
-	if (lstd == NULL) {
-		printf(uhci_check_intr: std==0\n);
-		return;
-	}
-#endif
+
+	KASSERT(lstd != NULL);
+
 	usb_syncmem(lstd-dma,
 	lstd-offs + offsetof(uhci_td_t, td_status),
 	sizeof(lstd-td.td_status),
@@ -1513,10 +1506,8 @@ void
 uhci_idone(uhci_intr_info_t *ii)
 {
 	struct usbd_xfer *xfer = ii-xfer;
+	uhci_softc_t *sc __diagused = xfer-ux_pipe-up_dev-ud_bus-ub_hcpriv;
 	struct uhci_pipe *upipe = (struct uhci_pipe *)xfer-ux_pipe;
-#ifdef DIAGNOSTIC
-	uhci_softc_t *sc = upipe-pipe.up_dev-ud_bus-ub_hcpriv;
-#endif
 	uhci_soft_td_t *std;
 	uint32_t status = 0, nstatus;
 	int actlen;
@@ -1527,23 +1518,16 @@ uhci_idone(uhci_intr_info_t *ii)
 	DPRINTFN(12, ii=%p, ii, 0, 0, 0);
 
 #ifdef DIAGNOSTIC
-	{
-		/* XXX SMP? */
-		int s = splhigh();
-		if (ii-isdone) {
-			splx(s);
 #ifdef UHCI_DEBUG
-			printf(uhci_idone: ii is done!\n   );
-			uhci_dump_ii(ii);
-#else
-			printf(uhci_idone: ii=%p is done!\n, ii);
-#endif
-			return;
-		}
-		ii-isdone = 1;
-		splx(s);
+	if (ii-isdone) {
+		DPRINTF(--- dump start ---, 0, 0, 0, 0);
+		uhci_dump_ii(ii);
+		DPRINTF(--- dump end ---, 0, 0, 0, 0);
 	}
 #endif
+	KASSERT(!ii-isdone);
+	ii-isdone = true;
+#endif
 
 	if (xfer-ux_nframes != 0) {
 		/* Isoc transfer, do things differently. */
@@ -1732,10 +1716,9 @@ uhci_waitintr(uhci_softc_t *sc, struct u
 	 ii != NULL  ii-xfer != xfer;
 	 ii = LIST_NEXT(ii, list))
 		;
-#ifdef DIAGNOSTIC
-	if (ii == NULL)
-		panic(uhci_waitintr: lost intr_info);
-#endif
+
+	KASSERT(ii != NULL);
+
 	uhci_idone(ii);
 
 done:
@@ -2076,10 +2059,7 @@ uhci_device_bulk_start(struct usbd_xfer 
 	if (sc-sc_dying)
 		return USBD_IOERROR;
 
-#ifdef DIAGNOSTIC
-	if (xfer-ux_rqflags  URQ_REQUEST)
-		panic(uhci_device_bulk_transfer: a request);
-#endif
+	KASSERT(!(xfer-ux_rqflags  URQ_REQUEST));
 
 	mutex_enter(sc-sc_lock);
 
@@ -2115,11 +2095,10 @@ uhci_device_bulk_start(struct usbd_xfer 
 	ii-xfer = xfer;
 	ii-stdstart = data;
 	ii-stdend = dataend;
+
+	KASSERT(ii-isdone);
 #ifdef DIAGNOSTIC
-	if (!ii-isdone) {
-		printf(uhci_device_bulk_transfer: not done, ii=%p\n, ii);
-	}
-	ii-isdone = 0;
+	ii-isdone = false;
 #endif
 
 	sqh-elink = data;
@@ -2153,9 +2132,7 @@ uhci_device_bulk_start(struct usbd_xfer 
 void
 uhci_device_bulk_abort(struct usbd_xfer *xfer)
 {
-#ifdef 

CVS commit: src/crypto/external/bsd/openssh

2015-04-03 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Apr  3 23:58:19 UTC 2015

Modified Files:
src/crypto/external/bsd/openssh/bin/ssh-keyscan: Makefile
src/crypto/external/bsd/openssh/dist: LICENCE OVERVIEW PROTOCOL
PROTOCOL.agent PROTOCOL.certkeys PROTOCOL.mux README addrmatch.c
atomicio.c atomicio.h auth-bsdauth.c auth-chall.c auth-krb5.c
auth-options.c auth-options.h auth-pam.c auth-pam.h auth-passwd.c
auth-rh-rsa.c auth-rhosts.c auth-rsa.c auth-skey.c auth.c auth.h
auth1.c auth2-chall.c auth2-gss.c auth2-hostbased.c auth2-kbdint.c
auth2-krb5.c auth2-none.c auth2-passwd.c auth2-pubkey.c auth2.c
authfd.c authfd.h authfile.c authfile.h bcrypt_pbkdf.c bitmap.c
bitmap.h blocks.c blowfish.c bufaux.c bufbn.c bufec.c buffer.c
buffer.h canohost.c canohost.h chacha.c channels.c channels.h
cipher-3des1.c cipher-bf1.c cipher-chachapoly.c cipher-ctr-mt.c
cipher.c cipher.h cleanup.c clientloop.c clientloop.h compat.c
compat.h crc32.c crc32.h deattack.c deattack.h dh.c dh.h
digest-libc.c digest-openssl.c dispatch.c dispatch.h dns.c dns.h
ed25519.c fatal.c fe25519.c fmt_scaled.c fmt_scaled.h ge25519.c
getpeereid.c getpeereid.h getrrsetbyname.c getrrsetbyname.h
groupaccess.c groupaccess.h gss-genr.c gss-serv-krb5.c gss-serv.c
hash.c hmac.c hostfile.c hostfile.h includes.h kex.c kex.h
kexc25519.c kexc25519c.c kexc25519s.c kexdh.c kexdhc.c kexdhs.c
kexecdh.c kexecdhc.c kexecdhs.c kexgex.c kexgexc.c kexgexs.c key.c
key.h krl.c ldapauth.c ldapauth.h log.c log.h mac.c mac.h match.c
match.h md-sha256.c misc.c misc.h moduli moduli.5 moduli.c
monitor.c monitor.h monitor_fdpass.c monitor_fdpass.h monitor_mm.c
monitor_mm.h monitor_wrap.c monitor_wrap.h msg.c msg.h mux.c
myproposal.h namespace.h nchan.c nchan.ms nchan2.ms opacket.c
opacket.h openssh2netbsd packet.c packet.h pathnames.h pkcs11.h
poly1305.c progressmeter.c progressmeter.h random.h readconf.c
readconf.h readpass.c readpassphrase.3 readpassphrase.c
readpassphrase.h roaming.h roaming_client.c roaming_common.c
roaming_dummy.c roaming_serv.c rsa.c rsa.h sandbox-rlimit.c
sc25519.c scp.1 scp.c servconf.c servconf.h serverloop.c
serverloop.h session.c session.h sftp-client.c sftp-client.h
sftp-common.c sftp-common.h sftp-glob.c sftp-server-main.c
sftp-server.8 sftp-server.c sftp.1 sftp.c sftp.h
smult_curve25519_ref.c ssh-add.1 ssh-add.c ssh-agent.1 ssh-agent.c
ssh-dss.c ssh-ecdsa.c ssh-ed25519.c ssh-gss.h ssh-keygen.1
ssh-keygen.c ssh-keyscan.1 ssh-keyscan.c ssh-keysign.8
ssh-keysign.c ssh-pkcs11-client.c ssh-pkcs11-helper.8
ssh-pkcs11-helper.c ssh-pkcs11.c ssh-pkcs11.h ssh-rsa.c ssh.1 ssh.c
ssh.h ssh1.h ssh2.h ssh_api.c ssh_api.h ssh_config ssh_config.5
sshbuf-getput-basic.c sshbuf-getput-crypto.c sshbuf-misc.c sshbuf.c
sshbuf.h sshconnect.c sshconnect.h sshconnect1.c sshconnect2.c
sshd.8 sshd.c sshd_config sshd_config.5 ssherr.c sshkey.c
sshlogin.c sshlogin.h sshpty.c sshpty.h sshtty.c ttymodes.c
ttymodes.h uidswap.c uidswap.h umac.c umac.h uuencode.c uuencode.h
verify.c version.h xmalloc.c xmalloc.h
src/crypto/external/bsd/openssh/lib: Makefile shlib_version
Removed Files:
src/crypto/external/bsd/openssh/dist: compress.c compress.h

Log Message:
Merge conflicts


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 \
src/crypto/external/bsd/openssh/bin/ssh-keyscan/Makefile
cvs rdiff -u -r1.3 -r1.4 src/crypto/external/bsd/openssh/dist/LICENCE \
src/crypto/external/bsd/openssh/dist/OVERVIEW \
src/crypto/external/bsd/openssh/dist/README \
src/crypto/external/bsd/openssh/dist/auth-bsdauth.c \
src/crypto/external/bsd/openssh/dist/auth-pam.h \
src/crypto/external/bsd/openssh/dist/auth-passwd.c \
src/crypto/external/bsd/openssh/dist/auth2-krb5.c \
src/crypto/external/bsd/openssh/dist/cleanup.c \
src/crypto/external/bsd/openssh/dist/crc32.c \
src/crypto/external/bsd/openssh/dist/crc32.h \
src/crypto/external/bsd/openssh/dist/deattack.c \
src/crypto/external/bsd/openssh/dist/deattack.h \
src/crypto/external/bsd/openssh/dist/dh.h \
src/crypto/external/bsd/openssh/dist/dispatch.c \
src/crypto/external/bsd/openssh/dist/dispatch.h \
src/crypto/external/bsd/openssh/dist/fatal.c \
src/crypto/external/bsd/openssh/dist/fmt_scaled.c \
src/crypto/external/bsd/openssh/dist/groupaccess.h \
src/crypto/external/bsd/openssh/dist/includes.h \
src/crypto/external/bsd/openssh/dist/kexdh.c \

CVS commit: src/sys

2015-04-03 Thread Tyler R. Retzlaff
Module Name:src
Committed By:   rtr
Date:   Sat Apr  4 04:33:39 UTC 2015

Modified Files:
src/sys/netinet: dccp_usrreq.c
src/sys/netinet6: dccp6_usrreq.c dccp6_var.h

Log Message:
* update dccp_bind for struct mbuf * to struct sockaddr * parameter change
* pass NULL instead of casting 0 to a pointer when calling in_pcbbind()


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/sys/netinet/dccp_usrreq.c
cvs rdiff -u -r1.1 -r1.2 src/sys/netinet6/dccp6_usrreq.c \
src/sys/netinet6/dccp6_var.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/netinet/dccp_usrreq.c
diff -u src/sys/netinet/dccp_usrreq.c:1.1 src/sys/netinet/dccp_usrreq.c:1.2
--- src/sys/netinet/dccp_usrreq.c:1.1	Tue Feb 10 19:11:52 2015
+++ src/sys/netinet/dccp_usrreq.c	Sat Apr  4 04:33:38 2015
@@ -1,5 +1,5 @@
 /*	$KAME: dccp_usrreq.c,v 1.67 2005/11/03 16:05:04 nishida Exp $	*/
-/*	$NetBSD: dccp_usrreq.c,v 1.1 2015/02/10 19:11:52 rjs Exp $ */
+/*	$NetBSD: dccp_usrreq.c,v 1.2 2015/04/04 04:33:38 rtr Exp $ */
 
 /*
  * Copyright (c) 2003 Joacim Häggmark, Magnus Erixzon, Nils-Erik Mattsson 
@@ -67,7 +67,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: dccp_usrreq.c,v 1.1 2015/02/10 19:11:52 rjs Exp $);
+__KERNEL_RCSID(0, $NetBSD: dccp_usrreq.c,v 1.2 2015/04/04 04:33:38 rtr Exp $);
 
 #include opt_inet.h
 #include opt_dccp.h
@@ -1820,12 +1820,11 @@ out:
 }
 
 static int
-dccp_bind(struct socket *so, struct mbuf *m, struct lwp *l)
+dccp_bind(struct socket *so, struct sockaddr *nam, struct lwp *l)
 {
 	struct inpcb *inp;
 	int error;
-	struct sockaddr_in *sinp;
-	struct sockaddr *nam;
+	struct sockaddr_in *sin = (struct sockaddr_in *)nam;
 
 	DCCP_DEBUG((LOG_INFO, Entering dccp_bind!\n));
 	INP_INFO_WLOCK(dccpbinfo);
@@ -1836,15 +1835,13 @@ dccp_bind(struct socket *so, struct mbuf
 	}
 
 	/* Do not bind to multicast addresses! */
-	nam = mtod(m, struct sockaddr *);
-	sinp = (struct sockaddr_in *)nam;
-	if (sinp-sin_family == AF_INET 
-	IN_MULTICAST(ntohl(sinp-sin_addr.s_addr))) {
+	if (sin-sin_family == AF_INET 
+	IN_MULTICAST(ntohl(sin-sin_addr.s_addr))) {
 		INP_INFO_WUNLOCK(dccpbinfo);
 		return EAFNOSUPPORT;
 	}
 	INP_LOCK(inp);
-	error = in_pcbbind(inp, m, l);
+	error = in_pcbbind(inp, sin, l);
 	INP_UNLOCK(inp);
 	INP_INFO_WUNLOCK(dccpbinfo);
 	return error;
@@ -1964,11 +1961,11 @@ dccp_doconnect(struct socket *so, struct
 #ifdef INET6
 		if (isipv6) {
 			DCCP_DEBUG((LOG_INFO, Running in6_pcbbind!\n));
-			error = in6_pcbbind(in6p, (struct mbuf *)0, l);
+			error = in6_pcbbind(in6p, NULL, l);
 		} else
 #endif /* INET6 */
 		{
-			error = in_pcbbind(inp, (struct mbuf *)0, l);
+			error = in_pcbbind(inp, NULL, l);
 		}
 		if (error) {
 			DCCP_DEBUG((LOG_INFO, in_pcbbind=%d\n,error));
@@ -2260,7 +2257,7 @@ dccp_listen(struct socket *so, struct lw
 	INP_INFO_RUNLOCK(dccpbinfo);
 	dp = (struct dccpcb *)inp-inp_ppcb;
 	if (inp-inp_lport == 0)
-		error = in_pcbbind(inp, (struct mbuf *)0, td);
+		error = in_pcbbind(inp, NULL, td);
 	if (error == 0) {
 		dp-state = DCCPS_LISTEN;
 		dp-who = DCCP_LISTENER;

Index: src/sys/netinet6/dccp6_usrreq.c
diff -u src/sys/netinet6/dccp6_usrreq.c:1.1 src/sys/netinet6/dccp6_usrreq.c:1.2
--- src/sys/netinet6/dccp6_usrreq.c:1.1	Tue Feb 10 19:11:52 2015
+++ src/sys/netinet6/dccp6_usrreq.c	Sat Apr  4 04:33:39 2015
@@ -1,5 +1,5 @@
 /*	$KAME: dccp6_usrreq.c,v 1.13 2005/07/27 08:42:56 nishida Exp $	*/
-/*	$NetBSD: dccp6_usrreq.c,v 1.1 2015/02/10 19:11:52 rjs Exp $ */
+/*	$NetBSD: dccp6_usrreq.c,v 1.2 2015/04/04 04:33:39 rtr Exp $ */
 
 /*
  * Copyright (C) 2003 WIDE Project.
@@ -31,7 +31,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: dccp6_usrreq.c,v 1.1 2015/02/10 19:11:52 rjs Exp $);
+__KERNEL_RCSID(0, $NetBSD: dccp6_usrreq.c,v 1.2 2015/04/04 04:33:39 rtr Exp $);
 
 #include opt_inet.h
 #include opt_dccp.h
@@ -111,12 +111,11 @@ dccp6_ctlinput(int cmd, const struct soc
 }
 
 int
-dccp6_bind(struct socket *so, struct mbuf *m, struct lwp *td)
+dccp6_bind(struct socket *so, struct sockaddr *nam, struct lwp *td)
 {
 	struct in6pcb *in6p;
-	struct sockaddr *nam;
 	int error;
-	struct sockaddr_in6 *sin6p;
+	struct sockaddr_in6 *sin6p = (struct sockaddr_in6 *)nam;
 
 	DCCP_DEBUG((LOG_INFO, Entering dccp6_bind!\n));
 	INP_INFO_WLOCK(dccpbinfo);
@@ -127,8 +126,6 @@ dccp6_bind(struct socket *so, struct mbu
 		return EINVAL;
 	}
 	/* Do not bind to multicast addresses! */
-	nam = mtod(m, struct sockaddr *);
-	sin6p = (struct sockaddr_in6 *)nam;
 	if (sin6p-sin6_family == AF_INET6 
 	IN6_IS_ADDR_MULTICAST(sin6p-sin6_addr)) {
 		INP_INFO_WUNLOCK(dccpbinfo);
@@ -139,7 +136,7 @@ dccp6_bind(struct socket *so, struct mbu
 	in6todccpcb(in6p)-inp_vflag = ~INP_IPV4;
 	in6todccpcb(in6p)-inp_vflag |= INP_IPV6;
 	
-	error = in6_pcbbind(in6p, m, td);
+	error = in6_pcbbind(in6p, sin6p, td);
 	INP_UNLOCK(inp);
 	INP_INFO_WUNLOCK(dccpbinfo);
 	return error;
@@ -253,7 

CVS commit: src/sys/arch/evbarm/conf

2015-04-03 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Fri Apr  3 23:52:51 UTC 2015

Modified Files:
src/sys/arch/evbarm/conf: GENERIC.common

Log Message:
use conf/filesystems.config


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/sys/arch/evbarm/conf/GENERIC.common

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/conf/GENERIC.common
diff -u src/sys/arch/evbarm/conf/GENERIC.common:1.1 src/sys/arch/evbarm/conf/GENERIC.common:1.2
--- src/sys/arch/evbarm/conf/GENERIC.common:1.1	Fri Apr  3 23:25:07 2015
+++ src/sys/arch/evbarm/conf/GENERIC.common	Fri Apr  3 23:52:51 2015
@@ -1,5 +1,5 @@
 #
-#	$NetBSD: GENERIC.common,v 1.1 2015/04/03 23:25:07 jmcneill Exp $
+#	$NetBSD: GENERIC.common,v 1.2 2015/04/03 23:52:51 jmcneill Exp $
 #
 #	GENERIC evbarm kernel config (template)
 #
@@ -19,24 +19,10 @@ options 	PMAPCOUNTERS
 # Architecture options
 
 # File systems
-
-file-system	FFS		# UFS
-#file-system	LFS		# log-structured file system
-file-system	MFS		# memory file system
-file-system	NFS		# Network file system
-#file-system 	ADOSFS		# AmigaDOS-compatible file system
-#file-system 	EXT2FS		# second extended file system (linux)
-#file-system	CD9660		# ISO 9660 + Rock Ridge file system
-file-system	MSDOSFS		# MS-DOS file system
-#file-system	FDESC		# /dev/fd
-file-system	KERNFS		# /kern
-#file-system	NULLFS		# loopback file system
-file-system	PROCFS		# /proc
-#file-system	PUFFS		# Userspace file systems (e.g. ntfs-3g  sshfs)
-#file-system	UMAPFS		# NULLFS + uid and gid remapping
-#file-system	UNION		# union file system
-file-system	TMPFS		# memory file system
-file-system	PTYFS		# /dev/pts/N support
+include conf/filesystems.config
+no file-system 	LFS
+no file-system 	CODA
+no pseudo-device vcoda
 
 # File system options
 #options 	QUOTA		# legacy UFS quotas
@@ -63,12 +49,12 @@ options 	INET6		# IPV6
 
 options 	NFS_BOOT_BOOTP
 #options 	NFS_BOOT_DHCP
-#options		NFS_BOOT_BOOTSTATIC
-#options		NFS_BOOTSTATIC_MYIP=\192.168.1.4\
-#options		NFS_BOOTSTATIC_GWIP=\192.168.1.1\
-#options		NFS_BOOTSTATIC_MASK=\255.255.255.0\
-#options		NFS_BOOTSTATIC_SERVADDR=\192.168.1.1\
-#options		NFS_BOOTSTATIC_SERVER=\192.168.1.1:/nfs/sdp2430\
+#options 	NFS_BOOT_BOOTSTATIC
+#options 	NFS_BOOTSTATIC_MYIP=\192.168.1.4\
+#options 	NFS_BOOTSTATIC_GWIP=\192.168.1.1\
+#options 	NFS_BOOTSTATIC_MASK=\255.255.255.0\
+#options 	NFS_BOOTSTATIC_SERVADDR=\192.168.1.1\
+#options 	NFS_BOOTSTATIC_SERVER=\192.168.1.1:/nfs/sdp2430\
 
 options		NFS_BOOT_RWSIZE=1024
 
@@ -147,7 +133,6 @@ options 	DDB_HISTORY_SIZE=100	# Enable h
 pseudo-device	vnd			# disk-like interface to files
 #pseudo-device	fss			# file system snapshot device
 pseudo-device	drvctl			# driver control
-pseudo-device	putter			# for puffs and pud
 
 # network pseudo-devices
 pseudo-device	bpfilter		# Berkeley packet filter



CVS commit: src/doc

2015-04-03 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sat Apr  4 00:03:12 UTC 2015

Modified Files:
src/doc: 3RDPARTY CHANGES

Log Message:
new openssh


To generate a diff of this commit:
cvs rdiff -u -r1.1216 -r1.1217 src/doc/3RDPARTY
cvs rdiff -u -r1.2063 -r1.2064 src/doc/CHANGES

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/3RDPARTY
diff -u src/doc/3RDPARTY:1.1216 src/doc/3RDPARTY:1.1217
--- src/doc/3RDPARTY:1.1216	Wed Apr  1 15:46:19 2015
+++ src/doc/3RDPARTY	Fri Apr  3 20:03:12 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: 3RDPARTY,v 1.1216 2015/04/01 19:46:19 christos Exp $
+#	$NetBSD: 3RDPARTY,v 1.1217 2015/04/04 00:03:12 christos Exp $
 #
 # This file contains a list of the software that has been integrated into
 # NetBSD where we are not the primary maintainer.
@@ -997,8 +997,8 @@ Notes:
 Patch applied after OpenSSH import.
 
 Package:	OpenSSH
-Version:	6.7
-Current Vers:	6.7 / portable 6.7p1
+Version:	6.8
+Current Vers:	6.8 / portable 6.8p1
 Maintainer:	OpenSSH
 Archive Site:	http://www.openssh.com/ftp.html
 Home Page:	http://www.openssh.com/portable.html

Index: src/doc/CHANGES
diff -u src/doc/CHANGES:1.2063 src/doc/CHANGES:1.2064
--- src/doc/CHANGES:1.2063	Wed Apr  1 15:46:19 2015
+++ src/doc/CHANGES	Fri Apr  3 20:03:12 2015
@@ -1,4 +1,4 @@
-# LIST OF CHANGES FROM LAST RELEASE:			$Revision: 1.2063 $
+# LIST OF CHANGES FROM LAST RELEASE:			$Revision: 1.2064 $
 #
 #
 # [Note: This file does not mention every change made to the NetBSD source tree.
@@ -148,3 +148,4 @@ Changes from NetBSD 7.0 to NetBSD 8.0:
 	libpcap: Import 1.7.2. [christos 20150331]
 	tcpdump(8): Import 4.7.3. [christos 20150331]
 	wpa: Import wpa_supplicant and hostapd 2.4. [christos 20150401]
+	OpenSSH: Imported 6.8. [christos 20150403]



CVS commit: src/distrib/sets/lists

2015-04-03 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sat Apr  4 00:00:41 UTC 2015

Modified Files:
src/distrib/sets/lists/base: ad.aarch64 ad.arm ad.mips ad.powerpc
ad.riscv md.amd64 md.sparc64 shl.mi
src/distrib/sets/lists/debug: ad.aarch64 ad.arm ad.mips ad.powerpc
ad.riscv md.amd64 md.sparc64 shl.mi

Log Message:
bump libssh


To generate a diff of this commit:
cvs rdiff -u -r1.20 -r1.21 src/distrib/sets/lists/base/ad.aarch64
cvs rdiff -u -r1.71 -r1.72 src/distrib/sets/lists/base/ad.arm
cvs rdiff -u -r1.65 -r1.66 src/distrib/sets/lists/base/ad.mips
cvs rdiff -u -r1.34 -r1.35 src/distrib/sets/lists/base/ad.powerpc
cvs rdiff -u -r1.16 -r1.17 src/distrib/sets/lists/base/ad.riscv
cvs rdiff -u -r1.261 -r1.262 src/distrib/sets/lists/base/md.amd64
cvs rdiff -u -r1.249 -r1.250 src/distrib/sets/lists/base/md.sparc64
cvs rdiff -u -r1.734 -r1.735 src/distrib/sets/lists/base/shl.mi
cvs rdiff -u -r1.19 -r1.20 src/distrib/sets/lists/debug/ad.aarch64
cvs rdiff -u -r1.60 -r1.61 src/distrib/sets/lists/debug/ad.arm
cvs rdiff -u -r1.55 -r1.56 src/distrib/sets/lists/debug/ad.mips
cvs rdiff -u -r1.35 -r1.36 src/distrib/sets/lists/debug/ad.powerpc
cvs rdiff -u -r1.16 -r1.17 src/distrib/sets/lists/debug/ad.riscv
cvs rdiff -u -r1.81 -r1.82 src/distrib/sets/lists/debug/md.amd64
cvs rdiff -u -r1.79 -r1.80 src/distrib/sets/lists/debug/md.sparc64
cvs rdiff -u -r1.95 -r1.96 src/distrib/sets/lists/debug/shl.mi

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/base/ad.aarch64
diff -u src/distrib/sets/lists/base/ad.aarch64:1.20 src/distrib/sets/lists/base/ad.aarch64:1.21
--- src/distrib/sets/lists/base/ad.aarch64:1.20	Tue Mar 31 17:40:57 2015
+++ src/distrib/sets/lists/base/ad.aarch64	Fri Apr  3 20:00:41 2015
@@ -1,4 +1,4 @@
-# $NetBSD: ad.aarch64,v 1.20 2015/03/31 21:40:57 christos Exp $
+# $NetBSD: ad.aarch64,v 1.21 2015/04/04 00:00:41 christos Exp $
 ./lib/eabi	base-compat-shlib	compat
 ./lib/eabi/npf	base-npf-shlib		compat
 ./lib/eabi/npf/ext_log.so			base-npf-shlib		compat,pic
@@ -297,8 +297,8 @@
 ./usr/lib/eabi/libsl.so.5.0			base-compat-shlib	compat,pic,kerberos
 ./usr/lib/eabi/libsqlite3.so.1			base-compat-shlib	compat,pic
 ./usr/lib/eabi/libsqlite3.so.1.2			base-compat-shlib	compat,pic
-./usr/lib/eabi/libssh.so.23			base-compat-shlib	compat,pic,crypto
-./usr/lib/eabi/libssh.so.23.0			base-compat-shlib	compat,pic,crypto
+./usr/lib/eabi/libssh.so.24			base-compat-shlib	compat,pic,crypto
+./usr/lib/eabi/libssh.so.24.0			base-compat-shlib	compat,pic,crypto
 ./usr/lib/eabi/libssl.so.10			base-compat-shlib	compat,pic,crypto
 ./usr/lib/eabi/libssl.so.10.5			base-compat-shlib	compat,pic,crypto
 ./usr/lib/eabi/libstdc++.so.7			base-compat-shlib	compat,pic,cxx,gcccmds,libstdcxx
@@ -615,8 +615,8 @@
 ./usr/lib/eabihf/libsl.so.5.0			base-compat-shlib	compat,pic,kerberos
 ./usr/lib/eabihf/libsqlite3.so.1			base-compat-shlib	compat,pic
 ./usr/lib/eabihf/libsqlite3.so.1.2			base-compat-shlib	compat,pic
-./usr/lib/eabihf/libssh.so.23			base-compat-shlib	compat,pic,crypto
-./usr/lib/eabihf/libssh.so.23.0			base-compat-shlib	compat,pic,crypto
+./usr/lib/eabihf/libssh.so.24			base-compat-shlib	compat,pic,crypto
+./usr/lib/eabihf/libssh.so.24.0			base-compat-shlib	compat,pic,crypto
 ./usr/lib/eabihf/libssl.so.10			base-compat-shlib	compat,pic,crypto
 ./usr/lib/eabihf/libssl.so.10.5			base-compat-shlib	compat,pic,crypto
 ./usr/lib/eabihf/libstdc++.so.7			base-compat-shlib	compat,pic,cxx,gcccmds,libstdcxx
@@ -931,8 +931,8 @@
 ./usr/lib/oabi/libsl.so.5.0			base-compat-shlib	compat,pic,kerberos
 ./usr/lib/oabi/libsqlite3.so.1			base-compat-shlib	compat,pic
 ./usr/lib/oabi/libsqlite3.so.1.2		base-compat-shlib	compat,pic
-./usr/lib/oabi/libssh.so.23			base-compat-shlib	compat,pic,crypto
-./usr/lib/oabi/libssh.so.23.0			base-compat-shlib	compat,pic,crypto
+./usr/lib/oabi/libssh.so.24			base-compat-shlib	compat,pic,crypto
+./usr/lib/oabi/libssh.so.24.0			base-compat-shlib	compat,pic,crypto
 ./usr/lib/oabi/libssl.so.10			base-compat-shlib	compat,pic,crypto
 ./usr/lib/oabi/libssl.so.10.5			base-compat-shlib	compat,pic,crypto
 ./usr/lib/oabi/libstdc++.so.7			base-compat-shlib	compat,pic,cxx,gcccmds,libstdcxx

Index: src/distrib/sets/lists/base/ad.arm
diff -u src/distrib/sets/lists/base/ad.arm:1.71 src/distrib/sets/lists/base/ad.arm:1.72
--- src/distrib/sets/lists/base/ad.arm:1.71	Tue Mar 31 17:40:57 2015
+++ src/distrib/sets/lists/base/ad.arm	Fri Apr  3 20:00:41 2015
@@ -1,4 +1,4 @@
-# $NetBSD: ad.arm,v 1.71 2015/03/31 21:40:57 christos Exp $
+# $NetBSD: ad.arm,v 1.72 2015/04/04 00:00:41 christos Exp $
 ./lib/oabi	base-compat-shlib	compat
 ./lib/oabi/npf	base-npf-shlib		compat
 ./lib/oabi/npf/ext_log.so			base-npf-shlib		compat,pic
@@ -303,8 +303,8 @@
 ./usr/lib/oabi/libsqlite3.so.1.2		base-compat-shlib	compat,pic
 ./usr/lib/oabi/libss.so.6			base-compat-shlib	obsolete
 

CVS commit: src/sys/arch/evbarm/conf

2015-04-03 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Fri Apr  3 23:25:08 UTC 2015

Modified Files:
src/sys/arch/evbarm/conf: ALLWINNER_A80 HUMMINGBIRD_A31 JETSONTK1
ODROID-C1 ROCKCHIP
Added Files:
src/sys/arch/evbarm/conf: GENERIC.common

Log Message:
Move common non-device stuff to GENERIC.common. Simplify board configs,
and let them all share common settings.


To generate a diff of this commit:
cvs rdiff -u -r1.14 -r1.15 src/sys/arch/evbarm/conf/ALLWINNER_A80
cvs rdiff -u -r0 -r1.1 src/sys/arch/evbarm/conf/GENERIC.common
cvs rdiff -u -r1.22 -r1.23 src/sys/arch/evbarm/conf/HUMMINGBIRD_A31
cvs rdiff -u -r1.2 -r1.3 src/sys/arch/evbarm/conf/JETSONTK1
cvs rdiff -u -r1.15 -r1.16 src/sys/arch/evbarm/conf/ODROID-C1
cvs rdiff -u -r1.19 -r1.20 src/sys/arch/evbarm/conf/ROCKCHIP

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/conf/ALLWINNER_A80
diff -u src/sys/arch/evbarm/conf/ALLWINNER_A80:1.14 src/sys/arch/evbarm/conf/ALLWINNER_A80:1.15
--- src/sys/arch/evbarm/conf/ALLWINNER_A80:1.14	Sun Dec 21 17:42:12 2014
+++ src/sys/arch/evbarm/conf/ALLWINNER_A80	Fri Apr  3 23:25:07 2015
@@ -1,22 +1,10 @@
-#	$NetBSD: ALLWINNER_A80,v 1.14 2014/12/21 17:42:12 jmcneill Exp $
+#	$NetBSD: ALLWINNER_A80,v 1.15 2015/04/03 23:25:07 jmcneill Exp $
 #
 #	ALLWINNER_A80 - Allwinner A80 boards (Cubieboard4, OptimusBoard, etc)
 #
 
 include	arch/evbarm/conf/std.awin
-
-#options 	VERBOSE_INIT_ARM
-
-# estimated number of users
-
-maxusers	32
-
-# Standard system options
-
-options 	RTC_OFFSET=0	# hardware clock is this many mins. west of GMT
-#options 	NTP		# NTP phase/frequency locked loop
-
-# CPU options
+include	arch/evbarm/conf/GENERIC.common
 
 no makeoptions	CPUFLAGS
 makeoptions	CPUFLAGS=-mcpu=cortex-a7 -mfpu=neon
@@ -27,165 +15,25 @@ no makeoptions	KERNEL_BASE_VIRT
 makeoptions 	KERNEL_BASE_PHYS=0x8000
 makeoptions 	KERNEL_BASE_VIRT=0x8000
 options 	PMAP_NEED_ALLOC_POOLPAGE
-#options 	UVMHIST,UVMHIST_PRINT
+
 options 	CPU_CORTEXA7
 options 	ALLWINNER_A80
-options 	PMAPCOUNTERS
+options 	MULTIPROCESSOR
+options 	MEMSIZE=2048
 options 	AWIN_CONSOLE_EARLY
 options 	AWIN_GPIO_IGNORE_FW
 
-# Architecture options
-
-# File systems
-
-file-system	FFS		# UFS
-#file-system	LFS		# log-structured file system
-file-system	MFS		# memory file system
-file-system	NFS		# Network file system
-#file-system 	ADOSFS		# AmigaDOS-compatible file system
-#file-system 	EXT2FS		# second extended file system (linux)
-#file-system	CD9660		# ISO 9660 + Rock Ridge file system
-file-system	MSDOSFS		# MS-DOS file system
-#file-system	FDESC		# /dev/fd
-file-system	KERNFS		# /kern
-#file-system	NULLFS		# loopback file system
-file-system	PROCFS		# /proc
-#file-system	PUFFS		# Userspace file systems (e.g. ntfs-3g  sshfs)
-#file-system	UMAPFS		# NULLFS + uid and gid remapping
-#file-system	UNION		# union file system
-file-system	TMPFS		# memory file system
-file-system	PTYFS		# /dev/pts/N support
-
-# File system options
-#options 	QUOTA		# legacy UFS quotas
-#options 	QUOTA2		# new, in-filesystem UFS quotas
-#options 	FFS_EI		# FFS Endian Independent support
-#options 	NFSSERVER
-options 	WAPBL		# File system journaling support
-#options 	FFS_NO_SNAPSHOT	# No FFS snapshot support
-
-# Networking options
-
-#options 	GATEWAY		# packet forwarding
-options 	INET		# IP + ICMP + TCP + UDP
-options 	INET6		# IPV6
-#options 	IPSEC		# IP security
-#options 	IPSEC_DEBUG	# debug for IP security
-#options 	MROUTING	# IP multicast routing
-#options 	PIM		# Protocol Independent Multicast
-#options 	NETATALK	# AppleTalk networking
-#options 	PPP_BSDCOMP	# BSD-Compress compression support for PPP
-#options 	PPP_DEFLATE	# Deflate compression support for PPP
-#options 	PPP_FILTER	# Active filter support for PPP (requires bpf)
-#options 	TCP_DEBUG	# Record last TCP_NDEBUG packets with SO_DEBUG
-
-options 	NFS_BOOT_BOOTP
-options 	NFS_BOOT_DHCP
-#options		NFS_BOOT_BOOTSTATIC
-#options		NFS_BOOTSTATIC_MYIP=\192.168.1.4\
-#options		NFS_BOOTSTATIC_GWIP=\192.168.1.1\
-#options		NFS_BOOTSTATIC_MASK=\255.255.255.0\
-#options		NFS_BOOTSTATIC_SERVADDR=\192.168.1.1\
-#options		NFS_BOOTSTATIC_SERVER=\192.168.1.1:/nfs/sdp2430\
-
-options		NFS_BOOT_RWSIZE=1024
-
-# Compatibility options
-
-options		COMPAT_NETBSD32	# allow running arm (e.g. non-earm) binaries
-#options 	COMPAT_43	# 4.3BSD compatibility.
-#options 	COMPAT_09	# NetBSD 0.9,
-#options 	COMPAT_10	# NetBSD 1.0,
-#options 	COMPAT_11	# NetBSD 1.1,
-#options 	COMPAT_12	# NetBSD 1.2,
-#options 	COMPAT_13	# NetBSD 1.3,
-#options 	COMPAT_14	# NetBSD 1.4,
-#options 	COMPAT_15	# NetBSD 1.5,
-#options 	COMPAT_16	# NetBSD 1.6,
-#options 	COMPAT_20	# NetBSD 2.0,
-options 	COMPAT_30	# NetBSD 3.0,
-options 	COMPAT_40	# NetBSD 4.0,
-options 	COMPAT_50	# NetBSD 5.0,
-options 	COMPAT_60	# NetBSD 6.0, and
-options 	COMPAT_70	# NetBSD 7.0 binary compatibility.
-#options 	TCP_COMPAT_42	# 4.2BSD TCP/IP 

CVS import: src/crypto/external/bsd/openssh/dist

2015-04-03 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Apr  3 23:49:28 UTC 2015

Update of /cvsroot/src/crypto/external/bsd/openssh/dist
In directory ivanova.netbsd.org:/tmp/cvs-serv26798

Log Message:
Changes since OpenSSH 6.7
=

This is a major release, containing a number of new features as
well as a large internal re-factoring.

Potentially-incompatible changes


 * sshd(8): UseDNS now defaults to 'no'. Configurations that match
   against the client host name (via sshd_config or authorized_keys)
   may need to re-enable it or convert to matching against addresses.

New Features


 * Much of OpenSSH's internal code has been re-factored to be more
   library-like. These changes are mostly not user-visible, but
   have greatly improved OpenSSH's testability and internal layout.

 * Add FingerprintHash option to ssh(1) and sshd(8), and equivalent
   command-line flags to the other tools to control algorithm used
   for key fingerprints. The default changes from MD5 to SHA256 and
   format from hex to base64.

   Fingerprints now have the hash algorithm prepended. An example of
   the new format: SHA256:mVPwvezndPv/ARoIadVY98vAC0g+P/5633yTC4d/wXE
   Please note that visual host keys will also be different.

 * ssh(1), sshd(8): Experimental host key rotation support. Add a
   protocol extension for a server to inform a client of all its
   available host keys after authentication has completed. The client
   may record the keys in known_hosts, allowing it to upgrade to better
   host key algorithms and a server to gracefully rotate its keys.

   The client side of this is controlled by a UpdateHostkeys config
   option (default off).

 * ssh(1): Add a ssh_config HostbasedKeyType option to control which
   host public key types are tried during host-based authentication.

 * ssh(1), sshd(8): fix connection-killing host key mismatch errors
   when sshd offers multiple ECDSA keys of different lengths.

 * ssh(1): when host name canonicalisation is enabled, try to
   parse host names as addresses before looking them up for
   canonicalisation. fixes bz#2074 and avoiding needless DNS
   lookups in some cases.

 * ssh-keygen(1), sshd(8): Key Revocation Lists (KRLs) no longer
   require OpenSSH to be compiled with OpenSSL support.

 * ssh(1), ssh-keysign(8): Make ed25519 keys work for host based
   authentication.

 * sshd(8): SSH protocol v.1 workaround for the Meyer, et al,
   Bleichenbacher Side Channel Attack. Fake up a bignum key before
   RSA decryption.

 * sshd(8): Remember which public keys have been used for
   authentication and refuse to accept previously-used keys.
   This allows AuthenticationMethods=publickey,publickey to require
   that users authenticate using two _different_ public keys.

 * sshd(8): add sshd_config HostbasedAcceptedKeyTypes and
   PubkeyAcceptedKeyTypes options to allow sshd to control what
   public key types will be accepted. Currently defaults to all.

 * sshd(8): Don't count partial authentication success as a failure
   against MaxAuthTries.

 * ssh(1): Add RevokedHostKeys option for the client to allow
   text-file or KRL-based revocation of host keys.

 * ssh-keygen(1), sshd(8): Permit KRLs that revoke certificates by
   serial number or key ID without scoping to a particular CA.

 * ssh(1): Add a Match canonical criteria that allows ssh_config
   Match blocks to trigger only in the second config pass.

 * ssh(1): Add a -G option to ssh that causes it to parse its
   configuration and dump the result to stdout, similar to sshd -T.

 * ssh(1): Allow Match criteria to be negated. E.g. Match !host.

 * The regression test suite has been extended to cover more OpenSSH
   features. The unit tests have been expanded and now cover key
   exchange.

Bugfixes

 * ssh-keyscan(1): ssh-keyscan has been made much more robust again
   servers that hang or violate the SSH protocol.

 * ssh(1), ssh-keygen(1): Fix regression bz#2306: Key path names were
   being lost as comment fields.

 * ssh(1): Allow ssh_config Port options set in the second config
   parse phase to be applied (they were being ignored). bz#2286

 * ssh(1): Tweak config re-parsing with host canonicalisation - make
   the second pass through the config files always run when host name
   canonicalisation is enabled (and not whenever the host name
   changes) bz#2267

 * ssh(1): Fix passing of wildcard forward bind addresses when
   connection multiplexing is in use; bz#2324;

 * ssh-keygen(1): Fix broken private key conversion from non-OpenSSH
   formats; bz#2345.

 * ssh-keygen(1): Fix KRL generation bug when multiple CAs are in
   use.

 * Various fixes to manual pages: bz#2288, bz#2316, bz#2273

Portable OpenSSH

 * Support --without-openssl at configure time

   Disables and removes dependency on OpenSSL. Many features,
   including SSH protocol 1 are not supported and the set of crypto
   options is greatly restricted. This will only work 

CVS commit: src/lib/libpam/modules/pam_ssh

2015-04-03 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sat Apr  4 02:51:10 UTC 2015

Modified Files:
src/lib/libpam/modules/pam_ssh: pam_ssh.c

Log Message:
Adapt to the new API.


To generate a diff of this commit:
cvs rdiff -u -r1.22 -r1.23 src/lib/libpam/modules/pam_ssh/pam_ssh.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libpam/modules/pam_ssh/pam_ssh.c
diff -u src/lib/libpam/modules/pam_ssh/pam_ssh.c:1.22 src/lib/libpam/modules/pam_ssh/pam_ssh.c:1.23
--- src/lib/libpam/modules/pam_ssh/pam_ssh.c:1.22	Fri Jan  6 09:04:02 2012
+++ src/lib/libpam/modules/pam_ssh/pam_ssh.c	Fri Apr  3 22:51:10 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: pam_ssh.c,v 1.22 2012/01/06 14:04:02 drochner Exp $	*/
+/*	$NetBSD: pam_ssh.c,v 1.23 2015/04/04 02:51:10 christos Exp $	*/
 
 /*-
  * Copyright (c) 2003 Networks Associates Technology, Inc.
@@ -38,7 +38,7 @@
 #ifdef __FreeBSD__
 __FBSDID($FreeBSD: src/lib/libpam/modules/pam_ssh/pam_ssh.c,v 1.40 2004/02/10 10:13:21 des Exp $);
 #else
-__RCSID($NetBSD: pam_ssh.c,v 1.22 2012/01/06 14:04:02 drochner Exp $);
+__RCSID($NetBSD: pam_ssh.c,v 1.23 2015/04/04 02:51:10 christos Exp $);
 #endif
 
 #include sys/param.h
@@ -352,11 +352,11 @@ done:
 static int
 pam_ssh_add_keys_to_agent(pam_handle_t *pamh)
 {
-	AuthenticationConnection *ac;
 	const struct pam_ssh_key *psk;
 	const char **kfn;
 	char **envlist, **env;
 	int pam_err;
+	int agent_fd;
 
 	/* switch to PAM environment */
 	envlist = environ;
@@ -368,11 +368,12 @@ pam_ssh_add_keys_to_agent(pam_handle_t *
 	}
 
 	/* get a connection to the agent */
-	if ((ac = ssh_get_authentication_connection()) == NULL) {
+	if (ssh_get_authentication_socket(agent_fd) != 0) {
 		openpam_log(PAM_LOG_DEBUG,
 		%s: cannot get authentication connection,
 		__func__);
 		pam_err = PAM_SYSTEM_ERR;
+		agent_fd = -1;
 		goto end;
 	}
 
@@ -382,7 +383,8 @@ pam_ssh_add_keys_to_agent(pam_handle_t *
 		pam_err = pam_get_data(pamh, *kfn, vp);
 		psk = vp;
 		if (pam_err == PAM_SUCCESS  psk != NULL) {
-			if (ssh_add_identity(ac, psk-key, psk-comment))
+			if (ssh_add_identity_constrained(agent_fd, psk-key,
+			psk-comment, 0, 0))
 openpam_log(PAM_LOG_DEBUG,
 added %s to ssh agent, psk-comment);
 			else
@@ -395,8 +397,8 @@ pam_ssh_add_keys_to_agent(pam_handle_t *
 	pam_err = PAM_SUCCESS;
  end:
 	/* disconnect from agent */
-	if (ac != NULL)
-		ssh_close_authentication_connection(ac);
+	if (agent_fd != -1)
+		ssh_close_authentication_socket(agent_fd);
 
 	/* switch back to original environment */
 	for (env = environ; *env != NULL; ++env)



CVS commit: src/sys/arch/arm/amlogic

2015-04-03 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Fri Apr  3 14:02:06 UTC 2015

Modified Files:
src/sys/arch/arm/amlogic: amlogic_board.c amlogic_crureg.h
amlogic_rng.c

Log Message:
Use a callback (with ugly lock dance from bcm2835_rng) instead of callout.
Make sure the ring oscillator is enabled as well.


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 src/sys/arch/arm/amlogic/amlogic_board.c
cvs rdiff -u -r1.7 -r1.8 src/sys/arch/arm/amlogic/amlogic_crureg.h
cvs rdiff -u -r1.1 -r1.2 src/sys/arch/arm/amlogic/amlogic_rng.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/amlogic/amlogic_board.c
diff -u src/sys/arch/arm/amlogic/amlogic_board.c:1.10 src/sys/arch/arm/amlogic/amlogic_board.c:1.11
--- src/sys/arch/arm/amlogic/amlogic_board.c:1.10	Sun Mar 29 22:49:44 2015
+++ src/sys/arch/arm/amlogic/amlogic_board.c	Fri Apr  3 14:02:06 2015
@@ -1,4 +1,4 @@
-/* $NetBSD: amlogic_board.c,v 1.10 2015/03/29 22:49:44 jmcneill Exp $ */
+/* $NetBSD: amlogic_board.c,v 1.11 2015/04/03 14:02:06 jmcneill Exp $ */
 
 /*-
  * Copyright (c) 2015 Jared D. McNeill jmcne...@invisible.ca
@@ -29,7 +29,7 @@
 #include opt_amlogic.h
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: amlogic_board.c,v 1.10 2015/03/29 22:49:44 jmcneill Exp $);
+__KERNEL_RCSID(0, $NetBSD: amlogic_board.c,v 1.11 2015/04/03 14:02:06 jmcneill Exp $);
 
 #define	_ARM32_BUS_DMA_PRIVATE
 #include sys/param.h
@@ -191,10 +191,10 @@ amlogic_eth_init(void)
 void
 amlogic_rng_init(void)
 {
-	CBUS_WRITE(EE_CLK_GATING0_REG,
-	CBUS_READ(EE_CLK_GATING0_REG) | EE_CLK_GATING0_RNG);
-	CBUS_WRITE(EE_CLK_GATING3_REG,
-	CBUS_READ(EE_CLK_GATING3_REG) | EE_CLK_GATING3_RNG);
+	CBUS_SET_CLEAR(EE_CLK_GATING0_REG, EE_CLK_GATING0_RNG, 0);
+	CBUS_SET_CLEAR(EE_CLK_GATING3_REG, EE_CLK_GATING3_RNG, 0);
+	CBUS_SET_CLEAR(AM_RING_OSC_REG,
+	AM_RING_OSC_ENABLE | AM_RING_OSC_HF_MODE, 0);
 }
 
 void

Index: src/sys/arch/arm/amlogic/amlogic_crureg.h
diff -u src/sys/arch/arm/amlogic/amlogic_crureg.h:1.7 src/sys/arch/arm/amlogic/amlogic_crureg.h:1.8
--- src/sys/arch/arm/amlogic/amlogic_crureg.h:1.7	Sun Mar  8 12:44:55 2015
+++ src/sys/arch/arm/amlogic/amlogic_crureg.h	Fri Apr  3 14:02:06 2015
@@ -1,4 +1,4 @@
-/* $NetBSD: amlogic_crureg.h,v 1.7 2015/03/08 12:44:55 jmcneill Exp $ */
+/* $NetBSD: amlogic_crureg.h,v 1.8 2015/04/03 14:02:06 jmcneill Exp $ */
 
 /*-
  * Copyright (c) 2015 Jared D. McNeill jmcne...@invisible.ca
@@ -107,6 +107,11 @@
 #define PAD_PULL_UP_EN_5_REG		CBUS_REG(0x204d)
 #define PAD_PULL_UP_EN_6_REG		CBUS_REG(0x204e)
 
+#define AM_RING_OSC_REG			CBUS_REG(0x207f)
+
+#define AM_RING_OSC_ENABLE		__BIT(0)
+#define AM_RING_OSC_HF_MODE		__BIT(1)
+
 #define PREI_USB_PHY_A_CFG_REG		CBUS_REG(0x2200)
 #define PREI_USB_PHY_A_CTRL_REG		CBUS_REG(0x2201)
 #define PREI_USB_PHY_A_ADP_BC_REG	CBUS_REG(0x2203)

Index: src/sys/arch/arm/amlogic/amlogic_rng.c
diff -u src/sys/arch/arm/amlogic/amlogic_rng.c:1.1 src/sys/arch/arm/amlogic/amlogic_rng.c:1.2
--- src/sys/arch/arm/amlogic/amlogic_rng.c:1.1	Sat Mar  7 21:34:25 2015
+++ src/sys/arch/arm/amlogic/amlogic_rng.c	Fri Apr  3 14:02:06 2015
@@ -1,4 +1,4 @@
-/* $NetBSD: amlogic_rng.c,v 1.1 2015/03/07 21:34:25 jmcneill Exp $ */
+/* $NetBSD: amlogic_rng.c,v 1.2 2015/04/03 14:02:06 jmcneill Exp $ */
 
 /*-
  * Copyright (c) 2015 Jared D. McNeill jmcne...@invisible.ca
@@ -29,7 +29,7 @@
 #include locators.h
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: amlogic_rng.c,v 1.1 2015/03/07 21:34:25 jmcneill Exp $);
+__KERNEL_RCSID(0, $NetBSD: amlogic_rng.c,v 1.2 2015/04/03 14:02:06 jmcneill Exp $);
 
 #include sys/param.h
 #include sys/bus.h
@@ -43,10 +43,14 @@ __KERNEL_RCSID(0, $NetBSD: amlogic_rng.
 #include arm/amlogic/amlogic_reg.h
 #include arm/amlogic/amlogic_var.h
 
+struct amlogic_rng_softc;
+
 static int	amlogic_rng_match(device_t, cfdata_t, void *);
 static void	amlogic_rng_attach(device_t, device_t, void *);
 
-static void	amlogic_rng_callout(void *);
+static void	amlogic_rng_get(struct amlogic_rng_softc *);
+static void	amlogic_rng_get_intr(void *);
+static void	amlogic_rng_get_cb(size_t, void *);
 
 struct amlogic_rng_softc {
 	device_t		sc_dev;
@@ -55,9 +59,11 @@ struct amlogic_rng_softc {
 
 	void *			sc_sih;
 
-	callout_t		sc_tick;
 	krndsource_t		sc_rndsource;
 	size_t			sc_bytes_wanted;
+
+	kmutex_t		sc_intr_lock;
+	kmutex_t		sc_rnd_lock;
 };
 
 CFATTACH_DECL_NEW(amlogic_rng, sizeof(struct amlogic_rng_softc),
@@ -81,31 +87,69 @@ amlogic_rng_attach(device_t parent, devi
 	bus_space_subregion(aio-aio_core_bst, aio-aio_bsh,
 	loc-loc_offset, loc-loc_size, sc-sc_bsh);
 
-	callout_init(sc-sc_tick, CALLOUT_MPSAFE);
-	callout_setfunc(sc-sc_tick, amlogic_rng_callout, sc);
-
+	mutex_init(sc-sc_intr_lock, MUTEX_DEFAULT, IPL_SERIAL);
+	mutex_init(sc-sc_rnd_lock, MUTEX_DEFAULT, IPL_SERIAL);
+	
 	amlogic_rng_init();
 
 	aprint_naive(\n);
 	aprint_normal(\n);
 
+	sc-sc_sih = 

CVS commit: src/sys/arch/arm/amlogic

2015-04-03 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Fri Apr  3 15:50:15 UTC 2015

Modified Files:
src/sys/arch/arm/amlogic: amlogic_com.c amlogic_comreg.h

Log Message:
Fix cnmagic handling, now I can enter ddb from serial console.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/sys/arch/arm/amlogic/amlogic_com.c
cvs rdiff -u -r1.3 -r1.4 src/sys/arch/arm/amlogic/amlogic_comreg.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/amlogic/amlogic_com.c
diff -u src/sys/arch/arm/amlogic/amlogic_com.c:1.4 src/sys/arch/arm/amlogic/amlogic_com.c:1.5
--- src/sys/arch/arm/amlogic/amlogic_com.c:1.4	Tue Mar  3 21:56:25 2015
+++ src/sys/arch/arm/amlogic/amlogic_com.c	Fri Apr  3 15:50:15 2015
@@ -1,4 +1,4 @@
-/* $NetBSD: amlogic_com.c,v 1.4 2015/03/03 21:56:25 jmcneill Exp $ */
+/* $NetBSD: amlogic_com.c,v 1.5 2015/04/03 15:50:15 jmcneill Exp $ */
 
 /*-
  * Copyright (c) 2013 The NetBSD Foundation, Inc.
@@ -33,7 +33,13 @@
 
 #include sys/cdefs.h
 
-__KERNEL_RCSID(1, $NetBSD: amlogic_com.c,v 1.4 2015/03/03 21:56:25 jmcneill Exp $);
+__KERNEL_RCSID(1, $NetBSD: amlogic_com.c,v 1.5 2015/04/03 15:50:15 jmcneill Exp $);
+
+#define cn_trap()			\
+	do {\
+		console_debugger();	\
+		cn_trapped = 1;		\
+	} while (/* CONSTCOND */ 0)
 
 #include sys/param.h
 #include sys/bus.h
@@ -430,14 +436,23 @@ amlogic_com_intr(void *priv)
 	uint32_t status, c;
 
 	for (;;) {
+		int cn_trapped = 0;
 		status = bus_space_read_4(sc-sc_bst, sc-sc_bsh,
 		UART_STATUS_REG);
 		if (status  UART_STATUS_RX_EMPTY) {
 			break;
 		}
+		if (status  UART_STATUS_BREAK) {
+			cn_check_magic(tp-t_dev, CNC_BREAK,
+			amlogic_com_cnm_state);
+			if (cn_trapped)
+continue;
+		}
 
 		c = bus_space_read_4(sc-sc_bst, sc-sc_bsh, UART_RFIFO_REG);
-		cn_check_magic(tp-t_dev, c, amlogic_com_cnm_state);
+		cn_check_magic(tp-t_dev, c  0xff, amlogic_com_cnm_state);
+		if (cn_trapped)
+			continue;
 		tp-t_linesw-l_rint(c  0xff, tp);
 	}
 

Index: src/sys/arch/arm/amlogic/amlogic_comreg.h
diff -u src/sys/arch/arm/amlogic/amlogic_comreg.h:1.3 src/sys/arch/arm/amlogic/amlogic_comreg.h:1.4
--- src/sys/arch/arm/amlogic/amlogic_comreg.h:1.3	Sun Mar  1 23:39:28 2015
+++ src/sys/arch/arm/amlogic/amlogic_comreg.h	Fri Apr  3 15:50:15 2015
@@ -1,4 +1,4 @@
-/* $NetBSD: amlogic_comreg.h,v 1.3 2015/03/01 23:39:28 jmcneill Exp $ */
+/* $NetBSD: amlogic_comreg.h,v 1.4 2015/04/03 15:50:15 jmcneill Exp $ */
 
 /*-
  * Copyright (c) 2015 Jared D. McNeill jmcne...@invisible.ca
@@ -49,6 +49,7 @@
 #define UART_STATUS_TX_EMPTY	__BIT(22)
 #define UART_STATUS_TX_FULL	__BIT(21)
 #define UART_STATUS_RX_EMPTY	__BIT(20)
+#define UART_STATUS_BREAK	__BIT(17)
 
 #define UART_MISC_TX_IRQ_CNT	__BITS(15,8)
 #define UART_MISC_RX_IRQ_CNT	__BITS(7,0)



CVS commit: src/lib/libc/time

2015-04-03 Thread Brian Ginsbach
Module Name:src
Committed By:   ginsbach
Date:   Fri Apr  3 15:52:51 UTC 2015

Modified Files:
src/lib/libc/time: strptime.3

Log Message:
Fix spelling; time zone is two words not one.


To generate a diff of this commit:
cvs rdiff -u -r1.29 -r1.30 src/lib/libc/time/strptime.3

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/time/strptime.3
diff -u src/lib/libc/time/strptime.3:1.29 src/lib/libc/time/strptime.3:1.30
--- src/lib/libc/time/strptime.3:1.29	Tue Apr 12 08:40:34 2011
+++ src/lib/libc/time/strptime.3	Fri Apr  3 15:52:50 2015
@@ -1,4 +1,4 @@
-.\	$NetBSD: strptime.3,v 1.29 2011/04/12 08:40:34 jruoho Exp $
+.\	$NetBSD: strptime.3,v 1.30 2015/04/03 15:52:50 ginsbach Exp $
 .\
 .\ Copyright (c) 1997, 1998, 2008 The NetBSD Foundation, Inc.
 .\ All rights reserved.
@@ -26,7 +26,7 @@
 .\ ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 .\ POSSIBILITY OF SUCH DAMAGE.
 .\
-.Dd April 12, 2011
+.Dd April  3, 2015
 .Dt STRPTIME 3
 .Os
 .Sh NAME
@@ -221,7 +221,7 @@ with \%C, specifies the year [0,99] wit
 .It Cm \%Y
 the year, including the century (i.e., 1996).
 .It Cm \%z
-an ISO 8601 or RFC-2822 timezone specification.
+an ISO 8601 or RFC-2822 time zone specification.
 This is one of the following:
 the offset from
 Coordinated Universal Time
@@ -240,7 +240,7 @@ specified as:
 or
 .Dq Z
 .Pq Ql Zulu Time ;
-a three character US timezone specified as:
+a three character US time zone specified as:
 .Dq EDT ,
 .Dq EST ,
 .Dq CDT ,
@@ -271,7 +271,7 @@ or
 .Ql Standard
 .Pq Dq S
 time;
-a single letter military timezone specified as:
+a single letter military time zone specified as:
 .Dq A
 through
 .Dq I
@@ -285,7 +285,7 @@ A
 extension.
 .Pc
 .It Cm \%Z
-timezone name or no characters when time zone information is unavailable.
+time zone name or no characters when time zone information is unavailable.
 .Po
 A
 .Nx
@@ -333,11 +333,11 @@ function conforms to
 .Sh BUGS
 The
 .Cm \%Z
-format specifier only accepts timezone
-abbreviations of the local timezone,
+format specifier only accepts time zone
+abbreviations of the local time zone,
 or the value
 .Dq GMT .
 This limitation is caused by the ambiguity
-of overloaded timezone abbreviations,
+of overloaded time zone abbreviations,
 for example EST is both Eastern Standard
 Time and Eastern Australia Summer Time.
Index: src/sys/rump/librump/rumpkern/lwproc.c
diff -u src/sys/rump/librump/rumpkern/lwproc.c:1.32 src/sys/rump/librump/rumpkern/lwproc.c:1.33
--- src/sys/rump/librump/rumpkern/lwproc.c:1.32	Wed Jan 21 14:39:37 2015
+++ src/sys/rump/librump/rumpkern/lwproc.c	Fri Apr  3 16:40:55 2015
@@ -1,4 +1,4 @@
-/*  $NetBSD: lwproc.c,v 1.32 2015/01/21 14:39:37 pooka Exp $	*/
+/*  $NetBSD: lwproc.c,v 1.33 2015/04/03 16:40:55 pooka Exp $	*/
 
 /*
  * Copyright (c) 2010, 2011 Antti Kantee.  All Rights Reserved.
@@ -28,7 +28,7 @@
 #define RUMP__CURLWP_PRIVATE
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: lwproc.c,v 1.32 2015/01/21 14:39:37 pooka Exp $);
+__KERNEL_RCSID(0, $NetBSD: lwproc.c,v 1.33 2015/04/03 16:40:55 pooka Exp $);
 
 #include sys/param.h
 #include sys/atomic.h
@@ -130,7 +130,7 @@ lwproc_proc_free(struct proc *p)
 	cv_destroy(p-p_waitcv);
 	cv_destroy(p-p_lwpcv);
 
 	/* non-kernel vmspaces are not shared */
 	if (!RUMP_LOCALPROC_P(p)) {
 		KASSERT(p-p_vmspace-vm_refcnt == 1);
 		kmem_free(p-p_vmspace, sizeof(*p-p_vmspace));
@@ -147,7 +147,7 @@ lwproc_proc_free(struct proc *p)
  * Switch to the new lwp and return a pointer to it.
  */
 static struct proc *
-lwproc_newproc(struct proc *parent, int flags)
+lwproc_newproc(struct proc *parent, struct vmspace *vm, int flags)
 {
 	uid_t uid = kauth_cred_getuid(parent-p_cred);
 	struct proc *p;
@@ -176,7 +176,7 @@ lwproc_newproc(struct proc *parent, int 
 
 	p-p_stats = pstatscopy(parent-p_stats);
 
-	p-p_vmspace = vmspace_kernel();
+	p-p_vmspace = vm;
 	p-p_emul = emul_default;
 #ifdef __HAVE_SYSCALL_INTERN
 	p-p_emul-e_syscall_intern(p);
@@ -327,7 +327,7 @@ rump__lwproc_alloclwp(struct proc *p)
 	bool newproc = false;
 
 	if (p == NULL) {
-		p = lwproc_newproc(proc0, 0);
+		p = lwproc_newproc(proc0, rump_vmspace_local, 0);
 		newproc = true;
 	}
 
@@ -368,7 +368,7 @@ rump_lwproc_newlwp(pid_t pid)
 }
 
 int
-rump_lwproc_rfork(int flags)
+rump_lwproc_rfork_vmspace(struct vmspace *vm, int flags)
 {
 	struct proc *p;
 	
@@ -130,7 +130,7 @@ lwproc_proc_free(struct proc *p)
 	cv_destroy(p-p_lwpcv);
 
-	/* non-kernel vmspaces are not shared */
+	/* non-local vmspaces are not shared */
 	if (!RUMP_LOCALPROC_P(p)) {
 		KASSERT(p-p_vmspace-vm_refcnt == 1);

CVS commit: src/sys/rump/librump/rumpkern

2015-04-03 Thread Antti Kantee
Module Name:src
Committed By:   pooka
Date:   Fri Apr  3 16:46:39 UTC 2015

Modified Files:
src/sys/rump/librump/rumpkern: rump_private.h vm.c
src/sys/rump/librump/rumpkern/arch/generic: rump_generic_pmap.c
src/sys/rump/librump/rumpkern/arch/x86: rump_x86_pmap.c

Log Message:
Use RUMP_PMAP_KERNEL and RUMP_PMAP_LOCAL to denote
kernel and local client pmaps, respectively.


To generate a diff of this commit:
cvs rdiff -u -r1.88 -r1.89 src/sys/rump/librump/rumpkern/rump_private.h
cvs rdiff -u -r1.162 -r1.163 src/sys/rump/librump/rumpkern/vm.c
cvs rdiff -u -r1.2 -r1.3 \
src/sys/rump/librump/rumpkern/arch/generic/rump_generic_pmap.c
cvs rdiff -u -r1.1 -r1.2 \
src/sys/rump/librump/rumpkern/arch/x86/rump_x86_pmap.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
